@@ -1,5 +1,5 @@
-/***             analog 5.24             http://www.analog.cx/             ***/
-/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
+/***             analog 5.32             http://www.analog.cx/             ***/
+/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2003 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
  *** with it. This program comes with no warranty, expressed or implied.   ***/
@@ -165,7 +165,7 @@ logical do_aliasr(char *name,  char *dirsuffix, unsigned int dirsufflength) {
   c = name;
   while ((c = strchr(c, '/')) != NULL && c < e2) {
     if (*(c + 1) == '/') {
-      if (*(c - 1) == ':' && c != name)
+      if (c != name && *(c - 1) == ':')
 	c++;   /* Don't translate http:// ; just skip to next /  */
       else
 	memmove((void *)(c + 1), (void *)(c + 2), strlen(c + 2) + 1);
@@ -269,6 +269,8 @@ logical do_aliasf(char *name) {
     defaultport = 21;
   else if (STREQ(name, "file"))
     return(FALSE);  /* don't count file: URL's */
+  else if (STREQ(name, "https"))
+    defaultport = 443;
   else if (STREQ(name, "news"))
     defaultport = 0;
   /* The rest probably never happen but they don't slow it down either because
@@ -663,15 +665,22 @@ void do_dns(char *name, char *alias, choice level) {
 	lp->other = submalloc(xmemman, strlen(name) + 1);
 	strcpy((char *)(lp->other), name);
 	if (dnsfilep != NULL) {
-	  fprintf(dnsfilep, "%ld %s %s\n", starttimeuxc, lp->name, name);
-	  fflush(dnsfilep);
+	  if (strchr(lp->name, ' ') == NULL && strchr(name, ' ') == NULL &&
+	      strlen(lp->name) + strlen(name) < 240) {
+	    /* otherwise will be corrupt at read time */
+	    fprintf(dnsfilep, "%ld %s %s\n", starttimeuxc, lp->name, name);
+	    fflush(dnsfilep);
+	  }
 	}
       }
       else {
 	lp->other = NULL;
 	if (dnsfilep != NULL) {
-	  fprintf(dnsfilep, "%ld %s *\n", starttimeuxc, lp->name);
-	  fflush(dnsfilep);
+	  if (strchr(lp->name, ' ') == NULL && strlen(lp->name) < 240) {
+	    /* otherwise will be corrupt at read time */
+	    fprintf(dnsfilep, "%ld %s *\n", starttimeuxc, lp->name);
+	    fflush(dnsfilep);
+	  }
 	}
       }
       lp->next = NULL;
