@@ -1,5 +1,5 @@
-/***             analog 5.24             http://www.analog.cx/             ***/
-/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
+/***             analog 5.32             http://www.analog.cx/             ***/
+/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2003 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
  *** with it. This program comes with no warranty, expressed or implied.   ***/
@@ -20,14 +20,13 @@ int main(int argc, char *argv[])
   extern FILE *dnsfilep, *dnslock;
 #endif
 
-  Filelist *logfilep;
+  Logfile *logfilep;
   Options *op;
   Inputformatlist *fmt;
   unsigned long linesread = 0, nextreport;
   ptrdiff_t corrupt_pos;
   time_t progfreqtime;
   struct tm *pflt;
-  FILE *lf;
   choice rc;
 
   op = (Options *)xmalloc(sizeof(Options));
@@ -40,9 +39,8 @@ int main(int argc, char *argv[])
 
   for (logfilep = op->miscopts.logfile[1]; logfilep != NULL;
        TO_NEXT(logfilep)) {
-    lf = my_lfopen(logfilep, "cache file");
-    if (lf != NULL) {
-      readcache(logfilep, lf, op->hash, op->no_cols, op->datacols,
+    if (my_lfopen(logfilep, "cache file")) {
+      readcache(logfilep, op->hash, op->no_cols, op->datacols,
 		op->data2cols, op->arraydata, op->wanthead, op->ispagehead,
 		&(op->dman), op->outopts.tree, op->outopts.derv,
 		op->outopts.alltrees, op->outopts.alldervs,
@@ -50,7 +48,7 @@ int main(int argc, char *argv[])
 		op->miscopts.dirsufflength, op->miscopts.usercase_insensitive,
 		op->outopts.convfloor, op->outopts.multibyte,
 		op->miscopts.granularity);
-      (void)my_lfclose(lf, logfilep, op->miscopts.logfile[1], NULL,
+      (void)my_lfclose(logfilep, op->miscopts.logfile[1], NULL,
 		       "cache file", &(op->dman), op->miscopts.data,
 		       &(op->miscopts.bytes), &(op->miscopts.bytes7));
     }
@@ -58,17 +56,16 @@ int main(int argc, char *argv[])
 
   for (logfilep = op->miscopts.logfile[0]; logfilep != NULL;
        TO_NEXT(logfilep)) {
-    lf = logfile_init(logfilep);
-    if (lf != NULL) {
+    if (logfile_init(logfilep)) {
       rc = FALSE;
       while (rc != EOF) {
 	corrupt_pos = -1;
 	record_start = pos;
 	for (fmt = logfilep->format, rc = FALSE; rc == FALSE && fmt != NULL;
 	     TO_NEXT(fmt)) {
-	  rc = parsenextrecord(lf, fmt->form);
+	  rc = parsenextrecord(logfilep, fmt->form);
 	  if (rc == TRUE) {
-	    process_data(logfilep, lf, op->hash, op->arraydata, fmt->count,
+	    process_data(logfilep, op->hash, op->arraydata, fmt->count,
 			 op->code2type, op->datacols, op->data2cols,
 			 op->no_cols, op->wanthead, op->ispagehead,
 			 op->aliashead, op->argshead, op->refargshead,
@@ -99,7 +96,7 @@ int main(int argc, char *argv[])
 	  }
 	}   /* end for(fmt) */
 	if (rc == FALSE)
-	  corrupt_line(lf, logfilep, "", corrupt_pos);
+	  corrupt_line(logfilep, "", corrupt_pos);
 	if ((++linesread) == nextreport) {
 	  time(&progfreqtime);
 	  pflt = localtime(&progfreqtime);
@@ -117,7 +114,7 @@ int main(int argc, char *argv[])
 	  MacIdle();
 #endif
       }   /* end while (rc != EOF) */
-      (void)my_lfclose(lf, logfilep, op->miscopts.logfile[1],
+      (void)my_lfclose(logfilep, op->miscopts.logfile[1],
 		       op->miscopts.logfile[0], "logfile", &(op->dman),
 		       op->miscopts.data, &(op->miscopts.bytes),
 		       &(op->miscopts.bytes7));
