@@ -1,5 +1,5 @@
-/***             analog 5.24             http://www.analog.cx/             ***/
-/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
+/***             analog 5.32             http://www.analog.cx/             ***/
+/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2003 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
  *** with it. This program comes with no warranty, expressed or implied.   ***/
@@ -384,8 +384,12 @@
 /* A separator string between fields in "computer" output style */
 
 #define RAWBYTES (FALSE)
-/* whether bytes should be quoted in full (e.g., 1,021,453) as opposed to
-   in kilobytes, megabytes etc. (e.g., 998k). */
+/* Whether bytes should be quoted in full (e.g., 1,021,453 bytes) as opposed
+   to in kilobytes, megabytes etc. (e.g., 997.5 kilobytes). */
+
+#define BYTESDP (2)
+/* If RAWBYTES is off, how many decimal places to display in the number of
+   bytes. */
 
 #define NOROBOTS (TRUE)
 /* Exclude SOME robots from indexing the output page or following its links. */
@@ -405,10 +409,11 @@
 /* Default language for the output page:
    ARMENIAN, BULGARIAN, BULGARIAN_MIK, CATALAN, TRAD_CHINESE (Big5), CZECH,
    CZECH_1250, DANISH, DUTCH, ENGLISH, US_ENGLISH, FINNISH, FRENCH, GERMAN,
-   HUNGARIAN, ITALIAN, JAPANESE_EUC, JAPANESE_JIS, JAPANESE_SJIS, JAPANESE_UTF,
+   HUNGARIAN, INDONESIAN, ITALIAN,
+   JAPANESE_EUC, JAPANESE_JIS, JAPANESE_SJIS, JAPANESE_UTF,
    KOREAN, LATVIAN, NORWEGIAN (Bokmal), NYNORSK, POLISH, PORTUGUESE,
-   BR_PORTUGUESE, RUSSIAN, RUSSIAN_1251, SERBIAN, SLOVENE, SLOVENE_1250,
-   SPANISH, SWEDISH, SWEDISH_ALT, TURKISH or UKRAINIAN.
+   BR_PORTUGUESE, RUSSIAN, RUSSIAN_1251, SERBIAN, SLOVAK, SLOVAK_1250,
+   SLOVENE, SLOVENE_1250, SPANISH, SWEDISH, SWEDISH_ALT, TURKISH or UKRAINIAN.
    *
    The following languages were available for previous versions of analog, but
    have not yet been translated for version 5. As they are translated, they
