@@ -1,5 +1,5 @@
-/***             analog 5.24             http://www.analog.cx/             ***/
-/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
+/***             analog 5.32             http://www.analog.cx/             ***/
+/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2003 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
  *** with it. This program comes with no warranty, expressed or implied.   ***/
@@ -14,7 +14,7 @@
 
 /*** OS specific things ***/
 
-#define VNUMBER "5.24"    /* the version number of this program */
+#define VNUMBER "5.32"    /* the version number of this program */
 
 #undef VERSION /* If no OS set, compilation will fail by not knowing VERSION */
 
@@ -39,7 +39,8 @@
 #ifdef MAC
 #define MAC_EVENTS
 #define NOPIPES
-#define MACDIRENT
+/* #define MACDIRENT */   /* No longer needed and POSIX dirent is better */
+#define NOGLOB
 #define NOFOLLOW
 #define NOOPEN
 #define NOALARM
@@ -146,15 +147,16 @@ extern void Win32Cleanup(void);
 #endif
 
 #ifdef RISCOS
-#define NODNS
+#define NOOPEN
 #define NOPIPES
-#define NODIRENT
+#define RISCOSDIRENT
 #define NOFOLLOW
 #define NOALARM
 #define PATHSEPS "."
 #define DIRSEP '.'
 #define EXTSEP '/'
-#define VERSION VNUMBER"/RISCOS"
+#define VERSION VNUMBER MINORVERSION"/RISCOS"
+#include <swis.h>
 #endif
 
 #ifdef NEXTSTEP
@@ -248,6 +250,7 @@ extern void Win32Cleanup(void);
 
 /*** system dependent header files ***/
 
+#include "zlib/zlib.h"
 #include "pcre/pcre.h"
 #include "libgd/gd.h"
 #include "libgd/gdfontf.h"
@@ -318,27 +321,34 @@ extern void mac_free(void *ptr);
 #ifndef VMSDIRENT
 #ifndef MACDIRENT
 #ifndef WIN32DIRENT
+#ifndef RISCOSDIRENT
 #ifndef NOGLOB
 #include <glob.h>            /* POSIX.2 glob */
 #else
-#include <sys/types.h>       /* POSIX dirent */
+#ifdef MAC
+#include <stat.h>            /* Mac POSIX dirent */
+#include <dirent.h>
+#else
+#include <sys/types.h>       /* Normal POSIX dirent */
 #include <dirent.h>
 #include <sys/stat.h>
-#endif
+#endif  /* MAC */
+#endif  /* NOGLOB */
+#endif  /* RISCOSDIRENT */
 #else
 #include <io.h>              /* Win32 dirent */
 #include <sys/types.h>
 #include <sys/stat.h>
-#endif
+#endif  /* WIN3DIRENT */
 #else
-#include "macdir.h"          /* Mac dirent */
+#include "macdir.h"          /* Old Mac dirent (no longer used) */
 #define NOGLOB
-#endif
+#endif  /* MACDIRENT */
 #else
 #define VMS_FSPEC_MAX 256    /* VMS dirent */
 #include <descrip.h>
-#endif
-#endif
+#endif  /* VMSDIRENT */
+#endif  /* NODIRENT */
 
 #ifndef NODNS
 #ifdef MAC
@@ -358,6 +368,9 @@ typedef unsigned long IN_ADDR_T;
 #ifdef WIN32    /* Win32 DNS: NB windows.h above includes winsock.h */
 #define INET_ADDR_ERR ((IN_ADDR_T)(INADDR_NONE))
 #else
+#ifdef RISCOS
+#include <sys/types.h>
+#endif
 #include <sys/socket.h>      /* Normal DNS */
 #include <netinet/in.h>
 #include <netdb.h>
@@ -430,10 +443,12 @@ typedef unsigned long IN_ADDR_T;
 #define NEWLOGFMT (2)
 #define BADLOGFMT (3)
 #define CONTINUATION (-1)  /* used in warn() in utils.c */
-#define REGEX_INC (2)  /* next four used in (struct include).type */
-#define NORMAL_INC (1) /* see also IS_REGEXT(), IS_INC() macros below */
+#define IPADDR_INC (3)   /* next six used in (struct include).type */
+#define REGEX_INC (2) /* see also IS_REGEXT(), IS_IPADDRT(), IS_INC() below */
+#define NORMAL_INC (1)
 #define NORMAL_EXC (-1)
 #define REGEX_EXC (-2)
+#define IPADDR_EXC (-3)
 #define BLOCK_EPSILON (30)
 #define MIN_SC (100)   /* see parsescode() in input.c */
 #define SC_NUMBER (600)
@@ -475,7 +490,6 @@ typedef unsigned long IN_ADDR_T;
 #define LNGSTR_NOEXT "[no extension]"
 #define LNGSTR_BRKDIRS "[directories]"
 #define LNGSTR_UNKWIN "Unknown Windows"
-#define LNGSTR_UNKMAC "Unknown Macintosh"
 #define LNGSTR_UNKUX "Other Unix"
 #define LNGSTR_ROBOTS "Robots"
 #define LNGSTR_UNKOS "OS unknown"
@@ -595,11 +609,12 @@ enum {SUNDAY, MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY};
 enum {ARMENIAN, /*BOSNIAN,*/ BULGARIAN, BULGARIAN_MIK, CATALAN,
       /*SIMP_CHINESE,*/ TRAD_CHINESE, /*CROATIAN,*/ CZECH, CZECH_1250, DANISH,
       DUTCH, ENGLISH, US_ENGLISH, FINNISH, FRENCH, GERMAN, /*GREEK,*/
-      HUNGARIAN, /*ICELANDIC,*/ ITALIAN, JAPANESE_EUC, JAPANESE_JIS,
+      HUNGARIAN, /*ICELANDIC,*/ INDONESIAN, ITALIAN, JAPANESE_EUC,
+      JAPANESE_JIS,
       JAPANESE_SJIS, JAPANESE_UTF, KOREAN, LATVIAN, /*LITHUANIAN,*/
       NORWEGIAN, NYNORSK, POLISH, PORTUGUESE, BR_PORTUGUESE, /*ROMANIAN,*/
-      RUSSIAN, RUSSIAN_1251, SERBIAN, /*SLOVAK,*/ SLOVENE, SLOVENE_1250,
-      SPANISH, SWEDISH, SWEDISH_ALT, TURKISH, UKRAINIAN};
+      RUSSIAN, RUSSIAN_1251, SERBIAN, SLOVAK, SLOVAK_1250, SLOVENE,
+      SLOVENE_1250, SPANISH, SWEDISH, SWEDISH_ALT, TURKISH, UKRAINIAN};
 #define OLDLANG (-2)
 
 /* source of data passed to htmlputs(): see comments there. These represent
@@ -615,7 +630,9 @@ enum {charset_, weekbeg_, year_, quarteryr_, month_, day_, days_, hr_, minute_,
       size_, search_, searches_, site_, sites_, user_, users_, code_, codes_,
       webstatsfor_, kilo_, mega_, giga_, tera_, peta_, exa_, zeta_, yotta_,
       kiloabbr_, megaabbr_, gigaabbr_, teraabbr_, petaabbr_, exaabbr_,
-      zetaabbr_, yottaabbr_, gensum_, yearrep_, busyyear_, quarterlyrep_,
+      zetaabbr_, yottaabbr_, filesize0_, filesize1_, filesize2_, filesize3_,
+      filesize4_, filesize5_, filesize6_, filesize7_, filesize8_, filesize9_,
+      filesize10_, gensum_, yearrep_, busyyear_, quarterlyrep_,
       busyquarteryr_, monthrep_, busymonth_, weekrep_, busyweek_, daysum_,
       dayrep_, busyday_, hourrep_, hoursum_, weekhoursum_, busyhour_,
       quarterrep_, quartersum_, busyquarterhr_, fiverep_, fivesum_, busyfive_,
@@ -645,7 +662,7 @@ enum {charset_, weekbeg_, year_, quarteryr_, month_, day_, days_, hr_, minute_,
       totredirs_, inforeqs_, distfiles_, disthosts_, corrupt_, unwanted_,
       totdata_, avedata_, brackets_, sevendaysto_, lastsevendays_, goto_, top_,
       unresolved_, nodomain_, unkdomain_, rootdir_, nodir_, noext_, brkdirs_,
-      unkwin_, unkmac_, unkux_, robots_, unkos_, nreqs_, nreqs7_, preqs_,
+      unkwin_, unkux_, robots_, unkos_, nreqs_, nreqs7_, preqs_,
       preqs7_, npgs_, npgs7_, ppgs_, ppgs7_, nbytes_, nxbytes_, nbytes7_,
       nxbytes7_, pbytes_, pbytes7_, index_, firstsm_, firstsf_, firstsn_,
       firstdsm_, firstdsf_, firstdsn_, allsm_, allsf_, allsn_, floorby_,
@@ -689,7 +706,20 @@ typedef signed char choice;
 typedef unsigned int datecode_t;
 typedef unsigned long timecode_t;
 
-/*** structs used in next section */
+/*** typedef function pointers ***/
+
+struct hashindex;
+struct logfile;
+
+typedef void (*cutfnp)(char **, char **, char *, logical);
+typedef void (*dcutfnp)(char **, char **, char *, void *);
+typedef struct hashindex *(*mergefnp)(struct hashindex *, struct hashindex *,
+				      unsigned long, unsigned long, choice);
+typedef void (*conffnp)(void *, char *, char *, char *, int);
+typedef choice (*inputfnp)(struct logfile *lf, void *, char);
+typedef size_t (*htmlstrlenp)(char *, choice);
+
+/*** structs */
 
 typedef struct {
   double bytes, bytes7;
@@ -728,18 +758,6 @@ typedef struct strpairlist {
   struct strpairlist *next;
 } Strpairlist;
 
-/*** typedef function pointers ***/
-
-typedef void (*cutfnp)(char **, char **, char *, logical);
-typedef void (*dcutfnp)(char **, char **, char *, void *);
-typedef struct hashindex *(*mergefnp)(struct hashindex *, struct hashindex *,
-				      unsigned long, unsigned long, choice);
-typedef void (*conffnp)(void *, char *, char *, char *, int);
-typedef choice (*inputfnp)(FILE *, void *, char);
-typedef size_t (*htmlstrlenp)(char *, choice);
-
-/*** rest of structs ***/
-
 typedef struct {
   char *name;
   conffnp fn;
@@ -771,8 +789,10 @@ typedef struct inputformatlist {
   struct inputformatlist *next;
 } Inputformatlist;
 
-typedef struct filelist {
+typedef struct logfile {
   char *name;
+  FILE *file;
+  gzFile gzfile;
   Inputformatlist *format;
   timecode_t from, to;
   unsigned long data[LOGDATA_NUMBER];
@@ -781,8 +801,8 @@ typedef struct filelist {
   size_t prefixlen;
   int pvpos, tz;
   logical ispipe;
-  struct filelist *next;
-} Filelist;
+  struct logfile *next;
+} Logfile;
 
 typedef struct mmlist {
   void *pos;
@@ -856,6 +876,7 @@ typedef struct {
 typedef struct include {
   char *name;
   pcre *pattern;
+  unsigned long minaddr, maxaddr;
   choice type;
   struct include *next;
 } Include;
@@ -893,8 +914,9 @@ typedef struct {
   char *hostname, *hosturl, *logo, *imagedir, *stylesheet;
   char *chartdir, *localchartdir;
   char markchar;
-  logical rawbytes;
   logical norobots;
+  logical rawbytes;
+  unsigned int bytesdp;
   choice weekbeginson;
   unsigned int plainpagewidth, htmlpagewidth, latexpagewidth, pagewidth;
   unsigned int mingraphwidth;
@@ -914,7 +936,7 @@ typedef struct {
 } Outchoices;
 
 typedef struct {
-  Filelist *logfile[2];  /* [0] are logfiles, [1] are cache files */
+  Logfile *logfile[2];  /* [0] are logfiles, [1] are cache files */
   unsigned long data[LOGDATA_NUMBER];
   double bytes, bytes7;
   char *dirsuffix;
@@ -1018,12 +1040,14 @@ typedef struct {
 /* The length of an n digit number with seps; e.g. 56789 [5] -> 56,789 [6] */
 #define COPYSTR(s, n) {char *z = n; s = (char *)xmalloc(strlen(z) + 1); \
                        strcpy(s, z);}  /* z needed so n only evaluated once */
+/* Note memory leak in COPYSTR, so only used in initialisation */
 #define TOO_FULL(n, z) ((n) > (z))   /* defn for hash table too full */
 #define TOO_FULL_TREE TOO_FULL
 #define NEW_SIZE(z) (2 * (z))        /* new size of the hash table */
 #define NEW_SIZE_TREE(z) (2 * (z) - 1)
-/* see ref to IS_REGEXT above; NB can't use >> with negative numbers */
-#define IS_REGEXT(type) ((type) / 2)  /* for includes */
+/* Next three: see IPADDR_INC etc. above */
+#define IS_IPADDRT(type) ((type) == 3 || (type) == -3)  /* for includes */
+#define IS_REGEXT(type) ((type) == 2 || (type) == -2)  /* for includes */
 #define IS_INC(type) ((type) > 0)     /* for includes */
 /* static char *s = NULL; static size_t len = 0; ENSURE_LEN(s, len, req_len) */
 #define ENSURE_LEN(s, l, n) if ((n) > (l)) { \
