@@ -1,5 +1,5 @@
-/***             analog 5.24             http://www.analog.cx/             ***/
-/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
+/***             analog 5.32             http://www.analog.cx/             ***/
+/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2003 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
  *** with it. This program comes with no warranty, expressed or implied.   ***/
@@ -61,9 +61,9 @@ extern void corruptcacheline(char *line, choice *rc, choice type);
 extern logical parsecacheline(char *linestart, char *parsestart,
   unsigned int *code, unsigned int maxcode, int no_items, unsigned long *data,
   double *bys, Memman *mm);
-extern void readoldcache(Filelist *cachefilep, FILE *lf, Dateman *dman,
-  choice type, unsigned int granularity);
-extern void readcache(Filelist *cachefilep, FILE *lf, Hashtable **hash,
+extern void readoldcache(Logfile *cachefilep, Dateman *dman, choice type,
+  unsigned int granularity);
+extern void readcache(Logfile *cachefilep, Hashtable **hash,
   unsigned int *no_cols,
   choice datacols[ITEM_NUMBER][OUTCOME_NUMBER][DATACOLS_NUMBER][2],
   choice data2cols[ITEM_NUMBER][DATA_NUMBER],
@@ -115,7 +115,7 @@ extern void initialise(int argc, char *argv[], Options *op);
 extern void confline(Options *op, char *cmd, char *arg1, char *arg2, int rc);
 extern choice config(char *filename, Options *op, logical fromcommandline);
 extern void settings(Options *op, int argc, char *argv[]);
-extern Inputformatlist *correctlogfmt(Filelist *lp, Include **wanthead,
+extern Inputformatlist *correctlogfmt(Logfile *lp, Include **wanthead,
   choice *code2type, Dateman *dman);
 extern void correct(Options *op);
 extern void finalinit(Options *op);
@@ -156,8 +156,8 @@ extern void configstrlist(void *opt, char *cmd, char *arg1, char *arg2,
 extern void configerrfile(void *opt, char *cmd, char *arg1, char *arg2,
   int rc);
 #ifndef NODIRENT
-extern Filelist *clonelogs(Filelist *from, char *name);
-extern Filelist *expandwildlogs(Filelist *lp, Filelist **pter);
+extern Logfile *clonelogs(Logfile *from, char *name);
+extern Logfile *expandwildlogs(Logfile *lp, Logfile **pter);
 #endif
 extern void configlogfile(void *opt, char *cmd, char *arg1, char *arg2,
   int rc);
@@ -196,48 +196,56 @@ extern void configincd(void *opt, char *cmd, char *arg1, char *arg2, int rc);
 extern void configexcd(void *opt, char *cmd, char *arg1, char *arg2, int rc);
 extern void configincs(void *opt, char *cmd, char *arg1, char *arg2, int rc);
 extern void configexcs(void *opt, char *cmd, char *arg1, char *arg2, int rc);
+logical parseiprange(char *arg1, unsigned long *minaddr,
+  unsigned long *maxaddr);
+extern void confighostinex(void *opt, char *cmd, char *arg1, char *arg2,
+  int rc, logical in);
+extern void confighostinc(void *opt, char *cmd, char *arg1, char *arg2,
+  int rc);
+extern void confighostexc(void *opt, char *cmd, char *arg1, char *arg2,
+  int rc);
 extern void configscinex(void *opt, char *cmd, char *arg1, char *arg2, int rc,
   logical in);
 extern void configscinc(void *opt, char *cmd, char *arg1, char *arg2, int rc);
 extern void configscexc(void *opt, char *cmd, char *arg1, char *arg2, int rc);
 
 /* in input.c */
-extern FILE *my_lfopen(Filelist *p, char *logtype);
+extern logical my_lfopen(Logfile *lf, char *logtype);
 extern FILE *my_fopen(char *name, char *logtype);
-extern int my_lfclose(FILE *f, Filelist *p, Filelist *allc, Filelist *allp,
-  char *filetype, Dateman *dman, unsigned long *totdata, double *bys,
-  double *bys7);
+extern int my_lfclose(Logfile *p, Logfile *allc, Logfile *allp, char *filetype,
+  Dateman *dman, unsigned long *totdata, double *bys, double *bys7);
 extern int my_fclose(FILE *f, char *name, char *filetype);
-extern FILE *logfile_init(Filelist *logfilep);
-extern choice getmoredata(FILE *f, char *start, size_t length);
+extern logical logfile_init(Logfile *lf);
+extern choice getmoredata(Logfile *lf, char *start, size_t length);
 extern choice getnextline(FILE *f, char *start, size_t used);
-extern void shunt_data(FILE *f);
+extern void shunt_data(Logfile *lf);
 extern int strtomonth(char *month);
-extern choice parsemonth(FILE *f, void *arg, char c);
-extern choice parseuint2(FILE *f, void *arg, char c);
-extern choice parsenmonth(FILE *f, void *arg, char c);
-extern choice parseulong(FILE *f, void *arg, char c);
-extern choice parseproctime(FILE *f, void *arg, char c);
-extern choice parseuint2strict(FILE *f, void *arg, char c);
-extern choice parsescode(FILE *f, void *arg, char c);
-extern choice parseuint4strict(FILE *f, void *arg, char c);
-extern choice parseudint(FILE *f, void *arg, char c);
-extern choice parseyear2(FILE *f, void *arg, char c);
-extern choice parseyear2or4(FILE *f, void *arg, char c);
-extern choice parseam(FILE *f, void *arg, char c);
-extern choice parsecode(FILE *f, void *arg, char c);
-extern choice parsejunk(FILE *f, void *arg, char c);
-extern choice parsespace(FILE *f, void *arg, char c);
-extern choice parseoptspace(FILE *f, void *arg, char c);
-extern choice parsenewline(FILE *f, void *arg, char c);
-extern void parsenonnewline(FILE *f);
-extern choice parsestring(FILE *f, void *arg, char c);
-extern choice parsemsbrow(FILE *f, void *arg, char c);
-extern choice parseref(FILE *f, void *arg, char c);
-extern choice checkchar(FILE *f, void *arg, char c);
+extern choice parsemonth(Logfile *lf, void *arg, char c);
+extern choice parseuint2(Logfile *lf, void *arg, char c);
+extern choice parsenmonth(Logfile *lf, void *arg, char c);
+extern choice parseulong(Logfile *lf, void *arg, char c);
+extern choice parseproctime(Logfile *lf, void *arg, char c);
+extern choice parseproctimeu(Logfile *lf, void *arg, char c);
+extern choice parseuint2strict(Logfile *lf, void *arg, char c);
+extern choice parsescode(Logfile *lf, void *arg, char c);
+extern choice parseuint4strict(Logfile *lf, void *arg, char c);
+extern choice parseudint(Logfile *lf, void *arg, char c);
+extern choice parseyear2(Logfile *lf, void *arg, char c);
+extern choice parseyear2or4(Logfile *lf, void *arg, char c);
+extern choice parseam(Logfile *lf, void *arg, char c);
+extern choice parsecode(Logfile *lf, void *arg, char c);
+extern choice parsejunk(Logfile *lf, void *arg, char c);
+extern choice parsespace(Logfile *lf, void *arg, char c);
+extern choice parseoptspace(Logfile *lf, void *arg, char c);
+extern choice parsenewline(Logfile *lf, void *arg, char c);
+extern void parsenonnewline(Logfile *lf);
+extern choice parsestring(Logfile *lf, void *arg, char c);
+extern choice parsemsbrow(Logfile *lf, void *arg, char c);
+extern choice parseref(Logfile *lf, void *arg, char c);
+extern choice checkchar(Logfile *lf, void *arg, char c);
 extern void resolveconflicts(unsigned int n, char *delims, ...);
-extern choice parselogfmt(FILE *f, void *arg, char c);
-extern choice parsenextrecord(FILE *f, Inputformat *format);
+extern choice parselogfmt(Logfile *lf, void *arg, char c);
+extern choice parsenextrecord(Logfile *lf, Inputformat *format);
 extern int parseconfline(char *s, char **cmd, char **arg1, char **arg2);
 extern int nextconfline(FILE *f, char **cmd, char **arg1, char **arg2);
 extern char *nextlngstr(FILE *f, char *name, logical want);
@@ -393,7 +401,7 @@ extern void piechart(FILE *outf, Outchoices *od, choice rep, Hashindex *items,
 #endif
 
 /* in process.c */
-extern void process_data(Filelist *logfilep, FILE *lf, Hashtable **hash,
+extern void process_data(Logfile *logfilep, Hashtable **hash,
   Arraydata **arraydata, choice *count, choice *code2type,
   choice datacols[ITEM_NUMBER][OUTCOME_NUMBER][DATACOLS_NUMBER][2],
   choice data2cols[ITEM_NUMBER][DATA_NUMBER], unsigned int *no_cols,
@@ -403,8 +411,7 @@ extern void process_data(Filelist *logfilep, FILE *lf, Hashtable **hash,
   logical case_insensitive, logical usercase_insensitive,
   unsigned char convfloor, logical multibyte, char *dirsuffix,
   unsigned int dirsufflength, unsigned int granularity);
-extern void corrupt_line(FILE *lf, Filelist *logfilep, char *message,
-  ptrdiff_t n);
+extern void corrupt_line(Logfile *logfilep, char *message, ptrdiff_t n);
 extern void arrayscore(Arraydata *array, double amount, unsigned long reqs,
   unsigned long reqs7, unsigned long pages, unsigned long pages7, double bytes,
   double bytes7, timecode_t timecode); 
@@ -414,7 +421,7 @@ extern void report_vbles(Options *op);
 extern void report_compile(void);
 extern void report_debug(char *type, char *arg, char *fullset);
 extern void report_conffiles(Strlist *list);
-extern void report_logfiles(Filelist *logfile, logical cache);
+extern void report_logfiles(Logfile *logfile, logical cache);
 extern void report_logformat(FILE *outf, Inputformatlist *format,
   logical inwarn);
 extern void report_fromto(Dateman *dman);
@@ -551,7 +558,8 @@ extern unsigned int chrn(char *s, char c);
 extern unsigned int chrdistn(char *s, char c);
 extern unsigned int log10i(unsigned long i);
 extern unsigned int log10x(double d);
-extern unsigned int findbmult(double d);
+extern unsigned int findbmult(double d, unsigned int dp);
+extern int atoi255(const char *s);
 extern unsigned long arraymaxl(unsigned long *x, unsigned int size);
 extern double arraymaxd(double *x, unsigned int size);
 extern size_t arraymaxlen(char **s, unsigned int size, choice outstyle);
@@ -576,6 +584,8 @@ extern logical matchq(char *s, void *p, logical is_regex, int *pmatch);
 extern logical genwildmatch(char *s, char *s2, char *p);
 extern logical headmatch(char *s, char *p);
 extern logical headcasematch(char *s, char *p);
+extern logical matchiprange(char *s, unsigned long minaddr,
+  unsigned long maxaddr);
 extern logical included(char *name, logical ispage, Include *listhead);
 extern logical incstrlist(char *name, Strlist *listhead);
 extern logical pageq(char *name, Include *ispagehead, choice type);
