@@ -1,5 +1,5 @@
-/***             analog 5.24             http://www.analog.cx/             ***/
-/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
+/***             analog 5.32             http://www.analog.cx/             ***/
+/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2003 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
  *** with it. This program comes with no warranty, expressed or implied.   ***/
@@ -106,10 +106,10 @@ char *methodname[] = {"requests","7-day requests", "pages", "7-day pages", "",
 		      "bytes", "7-day bytes", "alphabetical", "random"};
 /* Filenames for each language, in order of enum in anlghea3.h */
 char *country[] = {"am", /*"ba",*/ "bg", "bgm", "cat", /*"cn",*/ "tw",
-		   /*"hr",*/ "cz", "cz1", "dk", "nl", "uk", "us", "fi",
-		   "fr", "de", /*"gr",*/ "hu", /*"is",*/ "it", "jpe", "jpj",
+		   /*"hr",*/ "cz", "cz1", "dk", "nl", "uk", "us", "fi", "fr",
+		   "de", /*"gr",*/ "hu", /*"is",*/ "id", "it", "jpe", "jpj",
 		   "jps", "jpu", "kr", "lv", /*"lt",*/ "no", "no2", "pl", "pt",
-		   "br", /*"ro",*/ "ru", "ru1", "yu", /*"sk",*/ "si", "si1",
+		   "br", /*"ro",*/ "ru", "ru1", "yu", "sk", "sk1", "si", "si1",
 		   "es", "se", "se2", "tr", "ua"};
 /* Report code letters in order of enum in anlghea3.h */
 /* Any new ones must also be added to reportorder in anlghea2.h */
@@ -361,6 +361,7 @@ Inputfns inpfns[] = { /* first the ITEM fns in any order */
   {'U', INP_UNIXTIME, &parseulong, (void *)&unixtime},
   {'T', INP_PROCTIME, &parseulong, (void *)&proctime},
   {'t', INP_PROCTIME, &parseproctime, (void *)&proctime},
+  {'D', INP_PROCTIME, &parseproctimeu, (void *)&proctime},
   {'c', INP_CODE, &parsescode, (void *)&code},
   {'C', INP_CODE, &parsecode, (void *)&code},
   {'b', INP_BYTES, &parseudint, (void *)&bytes},
@@ -760,8 +761,8 @@ Configfns cf[] = {
   /* have to postpone SUBORG's until domains file has been read */
   {"FILEINCLUDE", &configinc, (void *)&(opts.wanthead[ITEM_FILE])},
   {"FILEEXCLUDE", &configexc, (void *)&(opts.wanthead[ITEM_FILE])},
-  {"HOSTINCLUDE", &configinc, (void *)&(opts.wanthead[ITEM_HOST])},
-  {"HOSTEXCLUDE", &configexc, (void *)&(opts.wanthead[ITEM_HOST])},
+  {"HOSTINCLUDE", &confighostinc, (void *)&(opts.wanthead[ITEM_HOST])},
+  {"HOSTEXCLUDE", &confighostexc, (void *)&(opts.wanthead[ITEM_HOST])},
   {"REFINCLUDE", &configinc, (void *)&(opts.wanthead[ITEM_REFERRER])},
   {"REFEXCLUDE", &configexc, (void *)&(opts.wanthead[ITEM_REFERRER])},
   {"BROWINCLUDE", &configinc, (void *)&(opts.wanthead[ITEM_BROWSER])},
@@ -783,17 +784,17 @@ Configfns cf[] = {
   {"TYPEEXCLUDE", &configexcd, (void *)&(opts.outopts.wanthead[G(REP_TYPE)])},
   {"DIRINCLUDE", &configincs, (void *)&(opts.outopts.wanthead[G(REP_DIR)])},
   {"DIREXCLUDE", &configexcs, (void *)&(opts.outopts.wanthead[G(REP_DIR)])},
-  {"HOSTREPINCLUDE", &configinc,
+  {"HOSTREPINCLUDE", &confighostinc,
    (void *)&(opts.outopts.wanthead[G(REP_HOST)])},
-  {"HOSTREPEXCLUDE", &configexc,
+  {"HOSTREPEXCLUDE", &confighostexc,
    (void *)&(opts.outopts.wanthead[G(REP_HOST)])},
-  {"REDIRHOSTINCLUDE", &configinc,
+  {"REDIRHOSTINCLUDE", &confighostinc,
    (void *)&(opts.outopts.wanthead[G(REP_REDIRHOST)])},
-  {"REDIRHOSTEXCLUDE", &configexc,
+  {"REDIRHOSTEXCLUDE", &confighostexc,
    (void *)&(opts.outopts.wanthead[G(REP_REDIRHOST)])},
-  {"FAILHOSTINCLUDE", &configinc,
+  {"FAILHOSTINCLUDE", &confighostinc,
    (void *)&(opts.outopts.wanthead[G(REP_FAILHOST)])},
-  {"FAILHOSTEXCLUDE", &configexc,
+  {"FAILHOSTEXCLUDE", &confighostexc,
    (void *)&(opts.outopts.wanthead[G(REP_FAILHOST)])},
   {"DOMINCLUDE", &configincd, (void *)&(opts.outopts.wanthead[G(REP_DOM)])},
   {"DOMEXCLUDE", &configexcd, (void *)&(opts.outopts.wanthead[G(REP_DOM)])},
@@ -1052,6 +1053,7 @@ Configfns cf[] = {
   {"FIVEBACK", &configchoice, (void *)&(opts.outopts.back[REP_FIVEREP])},
   {"FIVEREPBACK", &configchoice, (void *)&(opts.outopts.back[REP_FIVEREP])},
   {"RAWBYTES", &configchoice, (void *)&(opts.outopts.rawbytes)},
+  {"BYTESDP", &configuint, (void *)&(opts.outopts.bytesdp)},
   {"NOROBOTS", &configchoice, (void *)&(opts.outopts.norobots)},
   {"SETTINGS", &configchoice, (void *)&vblesonly},
   {"CGI", &configchoice, (void *)&cgi},
@@ -1508,7 +1510,8 @@ void defaults(Options *op) {
   double ptthresh[] = {0., 10., 20., 50., 100., 200., 500., 1000., 2000.,
 		       5000., 10000., 20000., 60000., 120000., 300000.,
 		       600000., -1.};
-  /* These thresholds have to be coordinated with the names in arrayrep() */
+  /* These thresholds have to be coordinated with the names in arrayrep().
+     The max codethresh & ptthresh also feature near the end of readcache(). */
   double *thresh;
   int i, j, k;
 
@@ -1812,6 +1815,7 @@ void defaults(Options *op) {
   op->outopts.barstyle = BARSTYLE;
   op->outopts.markchar = MARKCHAR;
   op->outopts.rawbytes = RAWBYTES;
+  op->outopts.bytesdp = BYTESDP;
   op->outopts.norobots = NOROBOTS;
   COPYSTR(op->outopts.hostname, HOSTNAME);
   COPYSTR(op->outopts.hosturl, HOSTURL);
