@@ -1,5 +1,5 @@
-/***             analog 5.24             http://www.analog.cx/             ***/
-/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
+/***             analog 5.32             http://www.analog.cx/             ***/
+/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2003 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
  *** with it. This program comes with no warranty, expressed or implied.   ***/
@@ -144,7 +144,7 @@ void settings(Options *op, int argc, char *argv[]) {
     error("Cannot ignore mandatory configuration file");
 }
 
-Inputformatlist *correctlogfmt(Filelist *lp, Include **wanthead,
+Inputformatlist *correctlogfmt(Logfile *lp, Include **wanthead,
 			       choice *code2type, Dateman *dman) {
   /* Here's a summary of what happens, minus several bells and whistles. At
      logfile parse time (strtoinfmt() below), fmt->count[ITEM] was set to 2 for
@@ -261,7 +261,7 @@ void correct(Options *op) {
   char *af = "ARGSFLOOR";
   char *ss = "SUBSORTBY";
   char *as = "ARGSSORTBY";
-  Filelist *lp;
+  Logfile *lp;
   Include *incp, *lastincp;
   choice rep, *cols, floor, subfloor, sortby, subsortby, chartby;
   char *subf, *subs, *c;
@@ -282,6 +282,11 @@ void correct(Options *op) {
 	 "Getting it from language file instead.");
     od->decpt = (char)UNSET;  /* and will be read from lang file */
   }
+  if (od->bytesdp > 6) {
+    warn('C', TRUE, "The maximum allowed value of BYTESDP is 6. "
+	 "For exact numbers, use RAWBYTES ON");
+    od->bytesdp = 6;
+  }
   op->dman.from = FIRST_TIME;
   if (op->dman.fromstr != NULL &&  /* so parse unless fromstr is NULL */
       parsedate(starttime, op->dman.fromstr, &(op->dman.from), TRUE, FALSE)
@@ -902,7 +907,7 @@ void finalinit(Options *op) {
   Outchoices *od = &(op->outopts);
   choice outstyle = od->outstyle;
 
-  Filelist *lp, *lastlp;
+  Logfile *lp, *lastlp;
   logical wantcol[ITEM_NUMBER][DATA_NUMBER];
   choice *cols;
   char **lngstr = NULL;  /* just to keep compiler happy */
@@ -963,9 +968,11 @@ void finalinit(Options *op) {
       if (!IS_STDIN(lp->name)) {
 	s = timesprintf(NULL, lp->name, op->dman.last7to, TRUE);
 	COPYSTR(lp->name, s);
+#ifndef NODIRENT
 	if (strchr(lp->name, '*') != NULL || strchr(lp->name, '?') != NULL)
 	  lp = expandwildlogs(lp, (lastlp == NULL)?\
 			      (&(op->miscopts.logfile[i])):(&(lastlp->next)));
+#endif
       }
     }
   }
@@ -1263,8 +1270,14 @@ void finalinit(Options *op) {
     for (i = 0; i < GENREP_NUMBER; i++)
       allgraft(od->tree[i]->tree, od->tree[i]->space,
 	       op->no_cols[rep2type[i + FIRST_GENREP]]);
-    for (sp = od->suborgs; sp != NULL; TO_NEXT(sp))
-      confline(op, "SUBORG2", sp->name, NULL, 1);
+    for (sp = od->suborgs; sp != NULL; TO_NEXT(sp)) {
+      if (strlen(sp->name) > 0 && sp->name[strlen(sp->name) - 1] == '*')
+	warn('C', TRUE, "SUBORG %s meaningless: must specify a domain because "
+	     "organisations are at different levels in different domains",
+	     sp->name);
+      else
+	confline(op, "SUBORG2", sp->name, NULL, 1);
+    }
     od->alltrees = (choice *)submalloc(xmemman, 6 * sizeof(choice));
     i = 0;
     POSSTREE(REP_DIR);
@@ -1299,7 +1312,6 @@ void finalinit(Options *op) {
       ALIASP("TYPEOUTPUTALIAS", LNGSTR_NOEXT, lngstr[noext_]);
       ALIASP("TYPEOUTPUTALIAS", LNGSTR_BRKDIRS, lngstr[brkdirs_]);
       ALIASP("OSOUTPUTALIAS", LNGSTR_UNKWIN, lngstr[unkwin_]);
-      ALIASP("OSOUTPUTALIAS", LNGSTR_UNKMAC, lngstr[unkmac_]);
       ALIASP("OSOUTPUTALIAS", LNGSTR_UNKUX, lngstr[unkux_]);
       ALIASP("OSOUTPUTALIAS", LNGSTR_UNKOS, lngstr[unkos_]);
       ALIASP("OSOUTPUTALIAS", LNGSTR_ROBOTS, lngstr[robots_]);
@@ -1394,8 +1406,8 @@ void finalinit(Options *op) {
   }  /* end if !vblesonly */
 }
 
-/* Now functions for turning strings into log formats */
-
+/* Now functions for turning strings into log formats. */
+/* The actual mapping of codes to functions is at inpfns[] in globals.c. */
 choice strtoinfmt(Inputformat **ans, char *s, choice *count) {
   /* For a discussion of count[], see correctlogfmt() above */
   extern Memman *xmemman;
@@ -1611,9 +1623,11 @@ char *apachelogfmt(char *fmt) {
 	strcat(ans, "[%d/%M/%Y:%h:%n:%j]");
       else if (*p == 'T')
 	strcat(ans, "%t");
+      else if (*p == 'D')
+	strcat(ans, "%D");
       else if (*p == 'q')
 	strcat(ans, "%q");
-      else if (*p == 'v' || *p == 'V')
+      else if (*p == 'A' || *p == 'v' || *p == 'V')
 	strcat(ans, "%v");
       else if (substrcaseeq(p, "{host}") && *(p + 6) == 'i') {
 	strcat(ans, "%v");
