@@ -1,5 +1,5 @@
-/***             analog 5.24             http://www.analog.cx/             ***/
-/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
+/***             analog 5.32             http://www.analog.cx/             ***/
+/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2003 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
  *** with it. This program comes with no warranty, expressed or implied.   ***/
@@ -210,7 +210,8 @@ Choices langchoices[] = {{"ARMENIAN", ARMENIAN}, {"BOSNIAN", OLDLANG},
   {"DANISH", DANISH}, {"DUTCH", DUTCH}, {"FLEMISH", DUTCH},
   {"ENGLISH", ENGLISH}, {"US-ENGLISH", US_ENGLISH}, {"FINNISH", FINNISH},
   {"FRENCH", FRENCH}, {"GERMAN", GERMAN}, {"GREEK", OLDLANG},
-  {"HUNGARIAN", HUNGARIAN}, {"ICELANDIC", OLDLANG}, {"ITALIAN", ITALIAN},
+  {"HUNGARIAN", HUNGARIAN}, {"ICELANDIC", OLDLANG}, {"INDONESIAN", INDONESIAN},
+  {"ITALIAN", ITALIAN},
   {"JAPANESE-EUC", JAPANESE_EUC}, {"JAPANESE-JIS", JAPANESE_JIS},
   {"JAPANESE-SJIS", JAPANESE_SJIS}, {"JAPANESE-UTF", JAPANESE_UTF},
   {"JAPANESE", JAPANESE_JIS}, {"KOREAN", KOREAN}, {"LATVIAN", LATVIAN},
@@ -221,7 +222,8 @@ Choices langchoices[] = {{"ARMENIAN", ARMENIAN}, {"BOSNIAN", OLDLANG},
   {"BRAZILIAN", BR_PORTUGUESE}, {"ROMANIAN", OLDLANG}, {"RUSSIAN", RUSSIAN},
   {"RUSSIAN-1251", RUSSIAN_1251},
   {"SERBIAN", SERBIAN}, {"SERBOCROATIAN", SERBIAN}, {"SERBOCROAT", SERBIAN},
-  {"SLOVAK", OLDLANG}, {"SLOVENE", SLOVENE}, {"SLOVENIAN", SLOVENE},
+  {"SLOVAK", SLOVAK}, {"SLOVAK-1250", SLOVAK_1250},
+  {"SLOVENE", SLOVENE}, {"SLOVENIAN", SLOVENE},
   {"SLOVENE-1250", SLOVENE_1250}, {"SLOVENIAN-1250", SLOVENE_1250},
   {"SPANISH", SPANISH},
   {"SWEDISH", SWEDISH}, {"SWEDISH-ALT", SWEDISH_ALT}, {"TURKISH", TURKISH},
@@ -765,20 +767,21 @@ void configerrfile(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
 /* There are several versions of expandwildlogs(), according to the following
    flags:
      NODIRENT excludes all wildcards in logfile names.
-     Otherwise, if VMSDIRENT, MACDIRENT or WIN32DIRENT is defined, use that.
+     Otherwise, if VMSDIRENT, MACDIRENT, WIN32DIRENT or RISCOSDIRENT is
+     defined, use that.
      Otherwise use POSIX.2 glob, unless NOGLOB is defined when use POSIX.1
      stuff, not allowing wildcards in directory names.
      MACDIRENT does actually include the POSIX.1 dirent code here, but
      implements all the functions itself in macstuff.c.
-   In all cases, expandwildlogs() takes an argument, Filelist *lp, and clones
+   In all cases, expandwildlogs() takes an argument, Logfile *lp, and clones
    it within the list (using clonelogs()) as it expands the wildcards. It
    returns a pointer to the last clone. E.g. expandwildlogs(log2*) turns
    log1 -> log2* -> log3 into log1 -> log2a -> log2b -> log3 returning log2b */
 #ifndef NODIRENT
-Filelist *clonelogs(Filelist *from, char *name) {
-  Filelist *ans = (Filelist *)xmalloc(sizeof(Filelist));
+Logfile *clonelogs(Logfile *from, char *name) {
+  Logfile *ans = (Logfile *)xmalloc(sizeof(Logfile));
 
-  memcpy(ans, from, sizeof(Filelist));
+  memcpy(ans, from, sizeof(Logfile));
   COPYSTR(ans->name, name);
   ans->next = from->next;
   from->next = ans;
@@ -787,11 +790,12 @@ Filelist *clonelogs(Filelist *from, char *name) {
 
 #ifndef VMSDIRENT
 #ifndef WIN32DIRENT
+#ifndef RISCOSDIRENT
 #ifndef NOGLOB
 /* Glob code is due to Owen Cliffe Feb 2001, slightly modified by
    Stephen Turner */
-Filelist *expandwildlogs(Filelist *lp, Filelist **pter) {
-  Filelist *ans = lp;
+Logfile *expandwildlogs(Logfile *lp, Logfile **pter) {
+  Logfile *ans = lp;
   glob_t globbuf;
   struct stat statbuf;
   int i;
@@ -813,8 +817,8 @@ Filelist *expandwildlogs(Filelist *lp, Filelist **pter) {
    return(ans);
 }
 #else   /* not GLOB; use POSIX dirent */
-Filelist *expandwildlogs(Filelist *lp, Filelist **pter) {
-  Filelist *ans = lp;
+Logfile *expandwildlogs(Logfile *lp, Logfile **pter) {
+  Logfile *ans = lp;
   struct dirent *filep;
   struct stat buf;
   DIR *dirp;
@@ -867,9 +871,67 @@ Filelist *expandwildlogs(Filelist *lp, Filelist **pter) {
   return(ans);
 }
 #endif   /* NOGLOB */
+#else    /* RISCOSDIRENT */
+/* The RISC OS dirent is due to Stefan Bellon */
+static struct {
+    unsigned int load, exec, length, attributes, type;
+    char name[255]; /* WARNING: arbitrary limit */
+} direntry;
+
+Logfile *expandwildlogs(Logfile *lp, Logfile **pter) {
+  Logfile *ans = lp;
+  char *dirname, *leafname, *filename, *c;
+  int count, context = 0;
+  _kernel_oserror *e;
+  size_t dirlen, path = 0, len = 0;
+
+  if ((c = strrpbrk(lp->name, PATHSEPS)) == NULL) {
+    path = 0;
+    dirname = (char *)xmalloc(1);
+    dirname[0] = '\0';
+    leafname = lp->name;
+  }
+  else {
+    path = 1;
+    dirname = (char *)xmalloc((size_t)(c - lp->name) + 1);
+    memcpy((void *)dirname, (void *)(lp->name), (size_t)(c - lp->name));
+    dirname[(c - lp->name)] = '\0';
+    leafname = c + 1;
+  }
+  dirlen = strlen(dirname);
+  filename = (char *)xmalloc(dirlen + path + 1);
+  memcpy(filename, dirname, dirlen);
+  filename[dirlen] = DIRSEP;
+  filename[dirlen + path] = '\0'; /* may overwrite the DIRSEP again */
+
+  while (context != -1) {
+    e = _swix(OS_GBPB, _INR(0,6) | _OUTR(3,4),
+              10, dirname, &direntry, 1, context, sizeof(direntry), leafname,
+              &count, &context);
+    if (e != NULL)
+      error("%s\n", e->errmess);
+
+    if (count > 0 && direntry.type == 1) {
+      if (strlen(direntry.name) > len) {
+        len = strlen(direntry.name);
+        filename = (char *)xrealloc((void *)filename, dirlen + path + len + 1);
+      }
+      memcpy((void *)(filename + dirlen + path),
+	     (void *)(direntry.name), len + 1);
+      ans = clonelogs(ans, filename);
+    }
+  }
+
+  free((void *)dirname);
+  free((void *)filename);
+  if (ans != lp)
+    *pter = lp->next;
+  return(ans);
+}
+#endif   /* RISCOSDIRENT */
 #else    /* WIN32DIRENT */
-Filelist *expandwildlogs(Filelist *lp, Filelist **pter) {
-  Filelist *ans = lp;
+Logfile *expandwildlogs(Logfile *lp, Logfile **pter) {
+  Logfile *ans = lp;
   struct _stat buf;
   char *dirname, *c;
   struct _finddata_t file;
@@ -909,8 +971,8 @@ Filelist *expandwildlogs(Filelist *lp, Filelist **pter) {
 #else    /* VMSDIRENT */
 /* This function is due to Dave Jones (except for any errors I introduced when
    converting from old configwildlogs() to new expandwildlogs()) */
-Filelist *expandwildlogs(Filelist *lp, Filelist **pter) {
-  Filelist *ans = lp;
+Logfile *expandwildlogs(Logfile *lp, Logfile **pter) {
+  Logfile *ans = lp;
   static char fspec[VMS_FSPEC_MAX], related[VMS_FSPEC_MAX];
   static char result[VMS_FSPEC_MAX];
   static $DESCRIPTOR(fspec_dx,fspec);
@@ -952,9 +1014,9 @@ void configlogfile(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
   /* see note in configcachefile() below re iscache */
   extern int tz;
 
-  Filelist **logfile = (Filelist **)opt;
+  Logfile **logfile = (Logfile **)opt;
   /* logfile[0] is logfiles, logfile[1] is cache files */
-  Filelist *lf;
+  Logfile *lf;
   char *s, *t;
   int i;
 
@@ -990,13 +1052,13 @@ void configlogfile(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
     newloglist = FALSE;
   }
   if (logfile[iscache] == NULL) {
-    logfile[iscache] = (Filelist *)xmalloc(sizeof(Filelist));
+    logfile[iscache] = (Logfile *)xmalloc(sizeof(Logfile));
     lf = logfile[iscache];
   }
   else {
     for (lf = logfile[iscache]; lf->next != NULL; TO_NEXT(lf))
       ;
-    lf->next = (Filelist *)xmalloc(sizeof(Filelist));
+    lf->next = (Logfile *)xmalloc(sizeof(Logfile));
     TO_NEXT(lf);
   }
   if (IS_STDIN(arg1) || rc == -2) {
@@ -1023,7 +1085,6 @@ void configlogfile(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
   }
   else
     lf->prefix = NULL;
-  lf->ispipe = FALSE;
   lf->next = NULL;
   if (!iscache)
     logformat->used = TRUE;
@@ -1031,7 +1092,7 @@ void configlogfile(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
 
 void configcachefile(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
   /* a wrapper to configlogfile(), but we have to catch a few cases first */
-  Filelist **logfile = (Filelist **)opt;
+  Logfile **logfile = (Logfile **)opt;
   extern logical iscache;
   /* iscache tells configlogfile() to use logfile[1] instead of logfile[0],
      not to change logformat->used, and to use CACHEDIR instead of LOGSDIR. */
@@ -1646,6 +1707,146 @@ void configexcs(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
   configinex(opt, cmd, arg1, arg2, rc, FALSE, FALSE, TRUE);
 }
 
+/* Try and interpret a string representing a range of IP addresses or a subnet
+   mask. Return whether successful. cf matchiprange() in utils.c.
+*/
+logical parseiprange(char *arg1, unsigned long *minaddr,
+		     unsigned long *maxaddr) {
+  unsigned long addr = 0, mask;
+  int n1, n2, octet, i;
+  char *arg, *tok, *sep, *c;
+
+  /* We only interpret ranges and subnet masks here, not single addresses or
+     wildcards, for example. Everything else is rejected so that it gets
+     submitted to normal string matching, which is more efficient.
+  */
+  if (!ISDIGIT(*arg1) || (strchr(arg1, '-') == NULL &&
+			  strchr(arg1, '/') == NULL))
+    return FALSE;
+
+  /* We can't use strtok here because it's already used in an outer loop in
+     confighostinex(), so we do it by hand. We first copy arg1 into arg so that
+     we don't have to worry about restoring arg1 afterwards.
+  */
+  COPYSTR(arg, arg1);
+  for (octet = 0, tok = arg; octet < 4 && tok != NULL; octet++, tok = sep) {
+
+    if ((sep = strchr(tok, '.')) != NULL) {
+      *sep = '\0';
+      sep++;  /* sep is now NULL if no more tokens, else start of next token */
+    }
+
+    /* Case 1: 131.111-114 or 131.111-114.* */
+    if ((c = strchr(tok, '-')) != NULL) {
+      *c = 0;
+      n1 = atoi255(tok);
+      n2 = atoi255(c + 1);
+      if (n1 < 0 || n2 <= n1)  /* includes n2 < 0 */
+	return FALSE;
+      /* Check just dots and stars left in the string. We don't bother checking
+	 for too many dots though. */
+      for (c = sep; c != NULL && *c != '\0'; c++) {
+	if (*c != '.' && *c != '*')
+	  return FALSE;
+      }
+      addr <<= 8 * (4 - octet);
+      *minaddr = addr + (n1 << 8 * (3 - octet));
+      *maxaddr = addr + (((n2 + 1) << 8 * (3 - octet)) - 1);
+      /* brackets essential to avoid underflow or overflow */
+      return TRUE;
+    }
+
+    /* Case 2: 131.111.20.18/24 */
+    if ((c = strchr(tok, '/')) != NULL) {
+      if (octet != 3)  /* slash only valid after last octet */
+	return FALSE;
+      if (sep != NULL && *sep != '\0')  /* check end of string */
+	return FALSE;
+      *c = 0;
+      n1 = atoi255(tok);
+      n2 = atoi255(c + 1);
+      if (n1 < 0 || n2 < 1 || n2 > 32)
+	return FALSE;
+      addr <<= 8;
+      addr += n1;
+      /* calculate subnet mask */
+      mask = 0;
+      for (i = 0; i < 32; i++) {
+	mask <<= 1;
+	mask += (i < n2);
+      }
+      addr &= mask;
+      *minaddr = addr;
+      *maxaddr = addr + ((1 << (32 - n2)) - 1);
+      /* brackets essential to avoid underflow or overflow */
+      return TRUE;
+    }
+
+    /* Case 3: The normal case: just the next number */
+    n1 = atoi255(tok);
+    if (n1 < 0)
+      return FALSE;
+    addr <<= 8;
+    addr += n1;
+
+  }  /* for octet */
+
+  /* We can only get here if we've read four octets but still not encountered
+     - or / . In that case, the string is corrupt. */
+  return FALSE;
+}
+
+/* For hosts, use confighostinex(). */
+/* First try parsing as a contiguous range of IP addresses, using
+   parseiprange() above. If that fails, pass to configinex for normal
+   processing. */
+void confighostinex(void *opt, char *cmd, char *arg1, char *arg2, int rc,
+		    logical in) {
+  Include **include = (Include **)opt;
+  Include *ip;
+  unsigned long minaddr, maxaddr;
+  char *c;
+
+  if (rc == 0) {
+    shortwarn(cmd, arg1, rc);
+    return;
+  }
+  if (rc > 1)
+    longwarn(cmd, arg1, arg2, rc);
+
+  if (strchr(arg1, ',') != NULL) {
+    if ((c = strtok(arg1, ",")) == NULL) {
+      badwarn(cmd, TRUE, arg1, arg2, rc);
+      return;
+    }
+    for ( ; c != NULL; c = strtok((char *)NULL, ","))
+      confighostinex(opt, cmd, c, NULL, 1, in);
+    return;
+  }
+
+  /* First try parsing the argument as a range of IP addresses. */
+  if (parseiprange(arg1, &minaddr, &maxaddr)) {
+    ip = *include;
+    *include = (Include *)xmalloc(sizeof(Include));
+    COPYSTR((*include)->name, arg1);
+    (*include)->minaddr = minaddr;
+    (*include)->maxaddr = maxaddr;
+    (*include)->next = ip;
+    (*include)->type = in?(IPADDR_INC):(IPADDR_EXC);
+  }
+  /* If that fails, parse to the regular string-like processing. */
+  else
+    configinex(opt, cmd, arg1, arg2, rc, in, FALSE, FALSE);
+}
+
+void confighostinc(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
+  confighostinex(opt, cmd, arg1, arg2, rc, TRUE);
+}
+
+void confighostexc(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
+  confighostinex(opt, cmd, arg1, arg2, rc, FALSE);
+}
+
 /* for status codes */
 void configscinex(void *opt, char *cmd, char *arg1, char *arg2, int rc,
 		  logical in) {
