@@ -1,5 +1,5 @@
-/***             analog 5.24             http://www.analog.cx/             ***/
-/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
+/***             analog 5.32             http://www.analog.cx/             ***/
+/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2003 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
  *** with it. This program comes with no warranty, expressed or implied.   ***/
@@ -11,8 +11,9 @@
 extern char *block_start, *block_end, *block_bell, *record_start, *pos;
 extern logical termchar[];
 static logical stdin_used = FALSE;
+static unsigned char gzmagic[2] = {0x1f, 0x8b}; /* gzip magic header */
 
-FILE *my_lfopen(Filelist *p, char *filetype)
+logical my_lfopen(Logfile *lf, char *filetype)
 {             /* open for reading */
 #ifndef NOPIPES
   extern Strpairlist *uncompresshead;
@@ -20,48 +21,76 @@ FILE *my_lfopen(Filelist *p, char *filetype)
   Strpairlist *up;
 #endif
 
-  FILE *f;
+  /* If the file is a gz file, we will set lf->gzfile -- otherwise we will set
+     lf->file, and lf->ispipe will record whether it's a pipe or not. */
+  lf->ispipe = FALSE;
+  lf->file = NULL;
+  lf->gzfile = NULL;
 
-  if (IS_STDIN(p->name)) {
+  if (IS_STDIN(lf->name)) {
     if (stdin_used) {
       warn('F', TRUE, "stdin already used; cannot use it as %s", filetype);
-      f = NULL;
+      return FALSE;
     }
     else {
-      f = stdin;
+      lf->file = stdin;
       stdin_used = TRUE;
       debug('F', "Opening stdin as %s", filetype);
+      return TRUE;
     }
   }
-  else {
-    if ((f = FOPENR(p->name)) == NULL)
-      warn('F', TRUE, "Failed to open %s %s: ignoring it", filetype, p->name);
-    else {
-      debug('F', "Opening %s as %s", p->name, filetype);
+
+  lf->file = FOPENR(lf->name);
+  if (lf->file == NULL) {
+    warn('F', TRUE, "Failed to open %s %s: ignoring it", filetype, lf->name);
+    return FALSE;
+  }
+
+  /* First see if it matches an UNCOMPRESS command: if so pass to a pipe */
 #ifndef NOPIPES
-      for (up = uncompresshead; up != NULL && !(p->ispipe); TO_NEXT(up)) {
-	if (strpbrk(p->name, "*?") == NULL && MATCHES(p->name, up->name)) {
-	  /* * and ? might be a security risk from the form: actually probably
-	     not because (i) they shouldn't get this far -- they are
-	     interpreted by configlogfile() unless they don't match anything;
-	     (ii) they probably wouldn't cause any harm anyway: but let's be
-	     over-cautious. */
-	  fclose(f);
-	  cmd = (char *)xmalloc(strlen(up->data) + strlen(p->name) + 4);
-	  if (strchr(p->name, ' ') != NULL)
-	    sprintf(cmd, "%s \"%s\"", up->data, p->name);
-	  else
-	    sprintf(cmd, "%s %s", up->data, p->name);
-	  f = POPENR(cmd);
-	  free((void *)cmd);
-	  p->ispipe = TRUE;
-	  debug('F', "  Using %s to uncompress it", up->data);
-	}
-      }
-#endif
+  for (up = uncompresshead; up != NULL; TO_NEXT(up)) {
+    if (strpbrk(lf->name, "*?") == NULL && MATCHES(lf->name, up->name)) {
+      /* * and ? might be a security risk from the form: actually probably
+	 not because (i) they shouldn't get this far -- they are interpreted by
+	 configlogfile() unless they don't match anything; (ii) they probably
+	 wouldn't cause any harm anyway: but let's be over-cautious.
+      */
+      fclose(lf->file);
+      cmd = (char *)xmalloc(strlen(up->data) + strlen(lf->name) + 4);
+      if (strchr(lf->name, ' ') != NULL)
+	sprintf(cmd, "%s \"%s\"", up->data, lf->name);
+      else
+	sprintf(cmd, "%s %s", up->data, lf->name);
+      lf->file = POPENR(cmd);
+      free((void *)cmd);
+      lf->ispipe = TRUE;
+      debug('F', "Opening %s as %s", lf->name, filetype);
+      debug('F', "  Using %s to uncompress it", up->data);
+      return TRUE;
     }
   }
-  return(f);
+#endif
+#ifndef LINE_PARSER   /* The Mac version has its own gzip detection */
+  /* If it didn't match an UNCOMPRESS, see if it's a gzipped file from its
+     first two bytes, and if so, use zlib. */
+  if ((unsigned char)(fgetc(lf->file)) == gzmagic[0] &&
+      (unsigned char)(fgetc(lf->file)) == gzmagic[1]) {
+    fclose(lf->file);
+    lf->file = NULL;
+    lf->gzfile = gzopen(lf->name, "rb");
+    if (lf->gzfile == NULL) {
+      warn('F', TRUE, "Failed to open %s %s as gzip file: ignoring it",
+	   filetype, lf->name);
+      return FALSE;
+    }
+    debug('F', "Opening %s as gzipped %s", lf->name, filetype);
+    return TRUE;
+  }
+  /* The normal case: just an ordinary file */
+  rewind(lf->file);
+#endif  /* LINE_PARSER */
+  debug('F', "Opening %s as %s", lf->name, filetype);
+  return TRUE;
 }
 
 FILE *my_fopen(char *name, char *filetype)
@@ -89,14 +118,14 @@ FILE *my_fopen(char *name, char *filetype)
 }
 
 #define LFCLOSE_DATEFMT "%d/%m/%y:%H%n"
-int my_lfclose(FILE *f, Filelist *p, Filelist *allc, Filelist *allp,
+int my_lfclose(Logfile *p, Logfile *allc, Logfile *allp,
 	       char *filetype, Dateman *dman, unsigned long *totdata,
 	       double *bys, double *bys7) {
   extern FILE *errfile;
   extern char *warn_args;
 
   unsigned long *data = p->data;
-  Filelist *ap, *nextap;
+  Logfile *ap, *nextap;
   Inputformatlist *fmt;
   choice count[INPUT_NUMBER];
   logical done;
@@ -173,15 +202,17 @@ int my_lfclose(FILE *f, Filelist *p, Filelist *allc, Filelist *allp,
 	   data[LOGDATA_INFO] + data[LOGDATA_UNKNOWN] > 0)
     debug('S', "No times in %s", filetype);
 
-  if (!(p->ispipe))
-    rc = fclose(f);    /* Not much can go wrong with fclose. I hope. */
+  if (p->gzfile != NULL)
+    rc = gzclose(p->gzfile);
+  else if (!(p->ispipe))
+    rc = fclose(p->file);    /* Not much can go wrong with fclose. I hope. */
 #ifndef NOPIPES
-  else if (feof(f)) {
-    if ((rc = pclose(f)) != 0)
+  else if (feof(p->file)) {
+    if ((rc = pclose(p->file)) != 0)
       warn('F', TRUE, "Problems uncompressing %s %s", filetype, p->name);
   }
   else
-    rc = pclose(f);  /* not reached EOF: pclose will return broken pipe */
+    rc = pclose(p->file); /* not reached EOF: pclose will return broken pipe */
 #endif
   return(rc);
 }
@@ -192,26 +223,35 @@ int my_fclose(FILE *f, char *name, char *filetype)
   return(fclose(f));
 }
 
-FILE *logfile_init(Filelist *logfilep) {
+logical logfile_init(Logfile *lf) {
   extern unsigned int year, code;
   extern double bytes;
 
-  if (logfilep->format == NULL) {
+  if (lf->format == NULL) {
     debug('F', "Ignoring logfile %s, which contains no items being analysed",
-	  logfilep->name);
-    return(NULL);
+	  lf->name);
+    return FALSE;
   }
   pos = NULL;
   year = 0;
   bytes = 0;
   code = 0;
-  return(my_lfopen(logfilep, "logfile"));
+  return(my_lfopen(lf, "logfile"));
 }
 
-choice getmoredata(FILE *f, char *start, size_t length) {
+choice getmoredata(Logfile *lf, char *start, size_t length) {
+  int n;
 
-  block_end = start + fread((void *)start, 1, length, f);
+  if (lf->gzfile == NULL)   /* normal file or pipe */
+    block_end = start + fread((void *)start, 1, length, lf->file);
+  else {  /* gz file */
+    n = gzread(lf->gzfile, (void *)start, length);
+    block_end = start + (size_t)((n < 0)?0:n); /* gzread returns -1 on error */
+  }
   block_bell = block_end - BLOCK_EPSILON;  /* saves repeating this calc. */
+
+  /* need to set block_end and block_bell even if returning EOF because still
+     have to parse the rest of the last line of the file */
   if (block_end == start)
     return(EOF);
   return(OK);
@@ -236,10 +276,10 @@ choice getnextline(FILE *f, char *start, size_t used) {
   return(TRUE);
 }
 
-void shunt_data(FILE *f) {
+void shunt_data(Logfile *lf) {
   memmove((void *)block_start, (void *)record_start,
 	  (size_t)(block_end - record_start));
-  (void)getmoredata(f, block_start + (block_end - record_start),
+  (void)getmoredata(lf, block_start + (block_end - record_start),
 		    (size_t)(BLOCKSIZE - (block_end - record_start)));
   pos -= record_start - block_start;
   record_start = block_start;
@@ -306,7 +346,7 @@ int strtomonth(char *m)  /* convert 3 letter month abbrev. to int */
   return(monthno);
 }
 
-choice parsemonth(FILE *f, void *arg, char c) {
+choice parsemonth(Logfile *lf, void *arg, char c) {
   unsigned int *m = (unsigned int *)arg;
 
   *block_end = '\0';
@@ -319,7 +359,7 @@ choice parsemonth(FILE *f, void *arg, char c) {
   }
 }
 
-choice parseuint2(FILE *f, void *arg, char c) {
+choice parseuint2(Logfile *lf, void *arg, char c) {
   unsigned int *x = (unsigned int *)arg;
 
   *block_end = '\0';
@@ -341,7 +381,7 @@ choice parseuint2(FILE *f, void *arg, char c) {
   return(TRUE);
 }
 
-choice parsenmonth(FILE *f, void *arg, char c) {  /* nearly same as uint2 */
+choice parsenmonth(Logfile *lf, void *arg, char c) { /* nearly same as uint2 */
   unsigned int *x = (unsigned int *)arg;
 
   *block_end = '\0';
@@ -367,7 +407,7 @@ choice parsenmonth(FILE *f, void *arg, char c) {  /* nearly same as uint2 */
   return(TRUE);
 }
 
-choice parseulong(FILE *f, void *arg, char c) {
+choice parseulong(Logfile *lf, void *arg, char c) {
   unsigned long *x = (unsigned long *)arg;
   register char *p = pos;
 
@@ -388,7 +428,22 @@ choice parseulong(FILE *f, void *arg, char c) {
   return(TRUE);
 }
 
-choice parseproctime(FILE *f, void *arg, char c) {
+/* Parse processing time in microseconds, convert to milliseconds */
+choice parseproctimeu(Logfile *lf, void *arg, char c) {
+  unsigned long *x;
+  choice rc;
+
+  rc = parseulong(lf, arg, c);
+  if (rc == FALSE)
+    return(FALSE);
+
+  x = (unsigned long *)arg;
+  *x /= 1000;
+
+  return(rc);
+}
+
+choice parseproctime(Logfile *lf, void *arg, char c) {
   /* parse processing time in decimal seconds, converting to milliseconds */
   unsigned long *x = (unsigned long *)arg;
   register char *p = pos;
@@ -435,7 +490,7 @@ choice parseproctime(FILE *f, void *arg, char c) {
   return(TRUE);
 }
 
-choice parseuint2strict(FILE *f, void *arg, char c) {
+choice parseuint2strict(Logfile *lf, void *arg, char c) {
   unsigned int *x = (unsigned int *)arg;
 
   *block_end = '\0';
@@ -451,7 +506,7 @@ choice parseuint2strict(FILE *f, void *arg, char c) {
   return(TRUE);
 }
 
-choice parsescode(FILE *f, void *arg, char c) {
+choice parsescode(Logfile *lf, void *arg, char c) {
   /* parseuint3strict() with twiddles */
   unsigned int *x = (unsigned int *)arg;
 
@@ -480,7 +535,7 @@ choice parsescode(FILE *f, void *arg, char c) {
   return(TRUE);
 }
 
-choice parseuint4strict(FILE *f, void *arg, char c) {
+choice parseuint4strict(Logfile *lf, void *arg, char c) {
   unsigned int *x = (unsigned int *)arg;
 
   *block_end = '\0';
@@ -506,7 +561,7 @@ choice parseuint4strict(FILE *f, void *arg, char c) {
   return(TRUE);
 }
 
-choice parseudint(FILE *f, void *arg, char c) {
+choice parseudint(Logfile *lf, void *arg, char c) {
   double *x = (double *)arg;
 
   *block_end = '\0';
@@ -528,11 +583,11 @@ choice parseudint(FILE *f, void *arg, char c) {
   return(TRUE);
 }
 
-choice parseyear2(FILE *f, void *arg, char c) {
+choice parseyear2(Logfile *lf, void *arg, char c) {
   unsigned int *y = (unsigned int *)arg;
   logical rc;
 
-  rc = parseuint2strict(f, arg, c);
+  rc = parseuint2strict(lf, arg, c);
   if (*y >= 70)
     *y += 1900;
   else
@@ -540,16 +595,16 @@ choice parseyear2(FILE *f, void *arg, char c) {
   return(rc);
 }
 
-choice parseyear2or4(FILE *f, void *arg, char c) {
+choice parseyear2or4(Logfile *lf, void *arg, char c) {
   if (*pos == '\0' || (*(pos + 1) == '\0'))
     return(FALSE);
   else if (ISDIGIT(*(pos + 2)))
-    return(parseuint4strict(f, arg, c));
+    return(parseuint4strict(lf, arg, c));
   else
-    return(parseyear2(f, arg, c));
+    return(parseyear2(lf, arg, c));
 }
 
-choice parseam(FILE *f, void *arg, char c) {
+choice parseam(Logfile *lf, void *arg, char c) {
   char *d = (char *)arg;
 
   *block_end = '\0';
@@ -562,12 +617,12 @@ choice parseam(FILE *f, void *arg, char c) {
     return(FALSE);
 }
 
-choice parsecode(FILE *f, void *arg, char c) {
+choice parsecode(Logfile *lf, void *arg, char c) {
   unsigned int *x = (unsigned int *)arg;
   char *d = pos, e, *g;
 
   *block_end = '\0';
-  if (parsejunk(f, NULL, c) == FALSE || pos == d)
+  if (parsejunk(lf, NULL, c) == FALSE || pos == d)
     return(FALSE);
   g = (c == WHITESPACE)?pos:(pos - 1);
   /* parsejunk normally leaves pos AFTER delimiter, but ON delimiter if
@@ -594,7 +649,7 @@ choice parsecode(FILE *f, void *arg, char c) {
   return(TRUE);
 }
 
-choice parsejunk(FILE *f, void *arg, char c) { /* NB allows empty strings */
+choice parsejunk(Logfile *lf, void *arg, char c) { /* NB allow empty strings */
   register char *p = pos;
 
   if (c == WHITESPACE) {
@@ -621,7 +676,7 @@ choice parsejunk(FILE *f, void *arg, char c) { /* NB allows empty strings */
       return(FALSE);
     }
     pos = p;
-    shunt_data(f);
+    shunt_data(lf);
     p = pos;
     *block_end = (c == WHITESPACE)?' ':c;
     while (!termchar[(unsigned char)(*p)])
@@ -659,39 +714,39 @@ choice parsejunk(FILE *f, void *arg, char c) { /* NB allows empty strings */
   return(TRUE);
 }
 
-choice parsespace(FILE *f, void *arg, char c) {
+choice parsespace(Logfile *lf, void *arg, char c) {
 
   *block_end = '\0';
   if (pos == block_end && record_start != block_start)
-    shunt_data(f);
+    shunt_data(lf);
   if (*pos != '\t' && *pos != ' ')
     return(FALSE);
   while (*pos == '\t' || *pos == ' ')
     pos++;
   if (pos == block_end && record_start != block_start) {
-    shunt_data(f);
+    shunt_data(lf);
     while (*pos == '\t' || *pos == ' ')
       pos++;
   }
   return(TRUE);
 }
 
-choice parseoptspace(FILE *f, void *arg, char c) {
+choice parseoptspace(Logfile *lf, void *arg, char c) {
 
   *block_end = '\0';
   if (pos == block_end && record_start != block_start)
-    shunt_data(f);
+    shunt_data(lf);
   while (*pos == '\t' || *pos == ' ')
     pos++;
   if (pos == block_end && record_start != block_start) {
-    shunt_data(f);
+    shunt_data(lf);
     while (*pos == '\t' || *pos == ' ')
       pos++;
   }
   return(TRUE);
 }
 
-choice parsenewline(FILE *f, void *arg, char c) {
+choice parsenewline(Logfile *lf, void *arg, char c) {
   /* allow new line to be preceded by white space */
   *block_end = 'a';
   if (*pos != '\n' && *pos != ' ' && *pos != '\r' && *pos != '\t')
@@ -699,7 +754,7 @@ choice parsenewline(FILE *f, void *arg, char c) {
   while (*pos == ' ' || *pos == '\t')
     pos++;
   if (pos == block_end && record_start != block_start) {
-    shunt_data(f);
+    shunt_data(lf);
     *block_end = 'a';
     while (*pos == ' ' || *pos == '\t')
       pos++;
@@ -711,7 +766,7 @@ choice parsenewline(FILE *f, void *arg, char c) {
   while (termchar[(unsigned char)(*pos)])
     pos++;
   if (pos == block_end && record_start != block_start) {
-    shunt_data(f);
+    shunt_data(lf);
     *block_end = 'a';
     while (termchar[(unsigned char)(*pos)])
       pos++;
@@ -720,7 +775,7 @@ choice parsenewline(FILE *f, void *arg, char c) {
   return(TRUE);
 }
 
-void parsenonnewline(FILE *f) {
+void parsenonnewline(Logfile *lf) {
 
   *block_end = '\n';
   termchar[(unsigned char)'\0'] = FALSE;
@@ -732,7 +787,7 @@ void parsenonnewline(FILE *f) {
       termchar[(unsigned char)'\0'] = TRUE;
       return;
     }
-    shunt_data(f);
+    shunt_data(lf);
     *block_end = '\n';
     while (!termchar[(unsigned char)(*pos)])
       pos++;
@@ -740,7 +795,7 @@ void parsenonnewline(FILE *f) {
   termchar[(unsigned char)'\0'] = TRUE;
 }
 
-choice parsestring(FILE *f, void *arg, char c) { /* NB allows empty strings */
+choice parsestring(Logfile *lf, void *arg, char c) { /*NB allow empty strings*/
   register char *p = pos;
   Memman *m = (Memman *)arg;
   size_t length = 0;
@@ -775,7 +830,7 @@ choice parsestring(FILE *f, void *arg, char c) { /* NB allows empty strings */
     }
     string_start -= record_start - block_start;
     pos = p;
-    shunt_data(f);
+    shunt_data(lf);
     p = pos;
     *block_end = (c == WHITESPACE)?' ':c;
     while (!termchar[(unsigned char)(*p)]) {
@@ -818,11 +873,11 @@ choice parsestring(FILE *f, void *arg, char c) { /* NB allows empty strings */
   return(TRUE);
 }
 
-choice parsemsbrow(FILE *f, void *arg, char c) {
+choice parsemsbrow(Logfile *lf, void *arg, char c) {
   Memman *m = (Memman *)arg;
   char *d;
 
-  if (parsestring(f, arg, c) == FALSE)
+  if (parsestring(lf, arg, c) == FALSE)
     return(FALSE);
   for (d = m->curr_pos; *d != '\0'; d++) {
     if (*d == '+')
@@ -831,7 +886,7 @@ choice parsemsbrow(FILE *f, void *arg, char c) {
   return(TRUE);
 }
 
-choice parseref(FILE *f, void *arg, char c) {
+choice parseref(Logfile *lf, void *arg, char c) {
   /* For referrer in old referrer logs: as parsestring except also checks ->
      immediately after delimiting character (presumably space: may not be \n
      or \r: also WHITESPACE wouldn't work so is disallowed in strtoinfmt()) */
@@ -862,7 +917,7 @@ choice parseref(FILE *f, void *arg, char c) {
     }
     string_start -= record_start - block_start;
     pos = p;
-    shunt_data(f);
+    shunt_data(lf);
     p = pos;
     *block_end = '\r';
     while (!termchar[(unsigned char)(*p)] ||
@@ -893,7 +948,7 @@ choice parseref(FILE *f, void *arg, char c) {
   return(TRUE);
 }
 
-choice checkchar(FILE *f, void *arg, char c) {
+choice checkchar(Logfile *lf, void *arg, char c) {
   if (*pos == c) {
     pos++;
     return(TRUE);
@@ -929,7 +984,7 @@ void resolveconflicts(unsigned int n, char *delims, ...) {
   va_end(ap);
 }
 
-choice parselogfmt(FILE *f, void *arg, char c) {
+choice parselogfmt(Logfile *lf, void *arg, char c) {
   extern Inputformatlist *logformat;
   static char *fmt = NULL;
   static size_t fmtlen = 0;
@@ -940,7 +995,7 @@ choice parselogfmt(FILE *f, void *arg, char c) {
   *block_end = '\n';
   d = strpbrk(pos, "\r\n");
   if (d == block_end) {
-    shunt_data(f);
+    shunt_data(lf);
     *block_end = '\n';
     d = strpbrk(pos, "\r\n");
     if (d == block_end)
@@ -1159,7 +1214,7 @@ choice parselogfmt(FILE *f, void *arg, char c) {
     configlogfmt((void *)&logformat, NULL, "WEBSTAR", NULL, -1);
     configlogfmt((void *)&logformat, NULL, fmt, NULL, -3);
     pos = d + 1;  /* start at next line */
-    (void)parsenewline(f, NULL, '\0');
+    (void)parsenewline(lf, NULL, '\0');
     break;
   case '3':  /* W3 extended format */
   case '5':  /* Microsoft's attempt at same */
@@ -1248,7 +1303,7 @@ choice parselogfmt(FILE *f, void *arg, char c) {
       configlogfmt((void *)&logformat, NULL, "WEBSTAR-EXTENDED", NULL, -1);
     configlogfmt((void *)&logformat, NULL, fmt, NULL, -3);
     pos = d + 1;
-    (void)parsenewline(f, NULL, '\0');
+    (void)parsenewline(lf, NULL, '\0');
     break;
   case '4':  /* Netscape format */
     resolveconflicts(2, "%", "Req->vars.auth-user", "Req->vars.pauth-user");
@@ -1304,22 +1359,22 @@ choice parselogfmt(FILE *f, void *arg, char c) {
     configlogfmt((void *)&logformat, NULL, "NETSCAPE", NULL, -1);
     configlogfmt((void *)&logformat, NULL, fmt, NULL, -3);
     pos = d + 1;
-    (void)parsenewline(f, NULL, '\0');
+    (void)parsenewline(lf, NULL, '\0');
     break;
   }
   return(NEWLOGFMT);
 }
 
-choice parsenextrecord(FILE *f, Inputformat *format) {
+choice parsenextrecord(Logfile *lf, Inputformat *format) {
   Inputformat *ipf, *ipf2;
   logical rc;
 
   if (pos == NULL) {   /* new logfile */
-    if (getmoredata(f, block_start, BLOCKSIZE) == EOF)
+    if (getmoredata(lf, block_start, BLOCKSIZE) == EOF)
       return(EOF);
     pos = block_start;
     if (*pos == '\n' || *pos == '\r')
-      parsenewline(f, NULL, '\0');   /* ignore completely blank lines at top */
+      parsenewline(lf, NULL, '\0');  /* ignore completely blank lines at top */
     record_start = pos;
   }
 
@@ -1329,12 +1384,12 @@ choice parsenextrecord(FILE *f, Inputformat *format) {
 
     if (pos > block_bell) {
       if (record_start != block_start)
-	shunt_data(f);
+	shunt_data(lf);
       if (pos == block_end && block_end - block_start < BLOCKSIZE)
 	return(EOF);
     }
 
-    rc = ipf->inpfns->fn(f, ipf->inpfns->opt, ipf->sep);
+    rc = ipf->inpfns->fn(lf, ipf->inpfns->opt, ipf->sep);
     if (rc != TRUE) {
       for (ipf2 = format; ipf2 != ipf; TO_NEXT(ipf2)) {
 	if (ipf2->inpfns->fn == &parsestring ||
