@@ -1,5 +1,5 @@
-/***             analog 5.24             http://www.analog.cx/             ***/
-/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
+/***             analog 5.32             http://www.analog.cx/             ***/
+/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2003 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
  *** with it. This program comes with no warranty, expressed or implied.   ***/
@@ -251,7 +251,7 @@ TryAEOpen(void)
 	long lvalue;
 	int cnt;
 	short refNum;
-	char c;
+	char c[2];
 
 	if (Gestalt(gestaltAppleEventsAttr,&lvalue)!=noErr) return(false);
 	result=noErr;
@@ -282,9 +282,9 @@ TryAEOpen(void)
 			}
 		}
 	if (haveFSS && !OpenFork(&myFSS,fsRdPerm,&refNum)) {
-		read(refNum,&c,1);
+		read(refNum,c,2);
 		close(refNum);
-		return(c);
+		return((c[0]=='#' && c[1]==' ')?'#':' ');
 		}
         return(0);
         }
