@@ -1,5 +1,5 @@
-/***             analog 5.24             http://www.analog.cx/             ***/
-/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
+/***             analog 5.32             http://www.analog.cx/             ***/
+/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2003 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
  *** with it. This program comes with no warranty, expressed or implied.   ***/
@@ -423,8 +423,14 @@ OpenInetServices(SvcInfo *svcInfo)
 
   svcInfo->done=false;
   if (!svcnotifyproc) svcnotifyproc=NewOTNotifyUPP(&SvcNotifyProc);
+#ifdef __CARBON__
+  
+  result=OTAsyncOpenInternetServicesInContext(kDefaultInternetServicesPath, 0,
+					      svcnotifyproc, svcInfo, NULL);
+#else
   result=OTAsyncOpenInternetServices(kDefaultInternetServicesPath, 0,
 				     svcnotifyproc, svcInfo);
+#endif
   if (!result) {
     do {
       MacIdle();
@@ -450,7 +456,11 @@ OpenNetwork(void)
     lCriteria = gestaltOpenTptPresentMask + gestaltOpenTptTCPPresentMask;
     lResponse = lCriteria & lResponse;
     if (lResponse == lCriteria)     {
+#ifdef __CARBON__
+      lStatus=InitOpenTransportInContext(kInitOTForApplicationMask,NULL);
+#else
       lStatus = InitOpenTransport();
+#endif
       if (lStatus == noErr) {
 	if (OpenInetServices(&sSvcRef)) {
 	  slNetSvcOpen=1;
