@@ -1,5 +1,5 @@
-/***             analog 5.24             http://www.analog.cx/             ***/
-/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
+/***             analog 5.32             http://www.analog.cx/             ***/
+/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2003 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
  *** with it. This program comes with no warranty, expressed or implied.   ***/
@@ -55,7 +55,8 @@ void pagetop(FILE *outf, Outchoices *od, Dateman *dman) {
 	htmlputs(outf, od, od->imagedir, IN_HREF);
       htmlputs(outf, od, od->logo, IN_HREF);
       if (STREQ(od->logo, "analogo"))
-	fprintf(outf, "%c%s", EXTSEP, od->pngimages?"png":"gif");
+	fprintf(outf, ".%s", od->pngimages?"png":"gif");
+      /* Above: '.' not EXTSEP even on RISC OS */
       fputs("\" alt=\"\"> ", outf);
     }
     if (strcaseeq(od->hosturl, "none")) {
@@ -198,7 +199,8 @@ void pagebot(FILE *outf, Outchoices *od) {
     fputs("<p><a href=\"http://validator.w3.org/\">\n", outf);
     fputs("<img src=\"", outf);
     htmlputs(outf, od, od->imagedir, IN_HREF);
-    fprintf(outf, "html2%c%s\"\n", EXTSEP, od->pngimages?"png":"gif");
+    fprintf(outf, "html2.%s\"\n", od->pngimages?"png":"gif");
+    /* Above: '.' not EXTSEP even on RISC OS */
     fputs("alt=\"HTML 2.0 Conformant!\"></a>\n", outf);
   }
   if (outstyle == HTML)
@@ -793,11 +795,8 @@ void dervrep(FILE *outf, Outchoices *od, choice rep, Hashindex *gooditems,
 }
 
 /* names for each bucket in arrayrep: see thresholds at top of defaults()...
-   in globals.c. (Names for code buckets are in the language files). */
-
-char *sizenames[] =
-{"0", "1b-  10b", "11b- 100b", "101b-  1kb", "1kb- 10kb", "10kb-100kb",
- "100kb-  1Mb", "1Mb- 10Mb", "10Mb-100Mb", "100Mb-  1Gb", "> 1Gb"};
+   in globals.c. (Names for status codes and file sizes are in the language
+   files). */
 
 char *ptnames1[] =
 {"0", "<= 0.01", "0.01-0.02", "0.02-0.05", "0.05-0.1 ", "0.1 -0.2 ",
@@ -822,7 +821,7 @@ void arrayrep(FILE *outf, Outchoices *od, choice rep, Arraydata *array,
   if (rep == REP_CODE)
     names = &(od->lngstr[code100_]);
   else if (rep == REP_SIZE)
-    names = sizenames;
+    names = &(od->lngstr[filesize0_]);
   else if (array[1].reqs + array[2].reqs + array[3].reqs + array[4].reqs +
 	   array[5].reqs + array[6].reqs == 0)  /* assume %t not %T */
     names = ptnames2;
@@ -885,8 +884,12 @@ void output(Outchoices *od, Hashindex **gooditems, Hashindex **baditems,
   else {
     if ((outf = FOPENW(outfile)) == NULL)
       error("failed to open output file %s for writing", outfile);
-    else
+    else {
       debug('F', "Opening %s as output file", outfile);
+#ifdef RISCOS
+      _swix(OS_File, _INR(0,2), 18, outfile, 0xfaf);  /* set filetype */
+#endif
+    }
   }
 
   /* remove any reports not wanted */
