@@ -1,5 +1,5 @@
-/***             analog 5.24             http://www.analog.cx/             ***/
-/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
+/***             analog 5.32             http://www.analog.cx/             ***/
+/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2003 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
  *** with it. This program comes with no warranty, expressed or implied.   ***/
@@ -382,7 +382,7 @@ void latexfprintf(FILE *outf, char *s) {
       PUTc(w, *c);
       len += 1;
     }
-    if (len > 57) {
+    if (len > 50) {
       *w = '\0';
       fputs(w1, outf);
       w = w1;
@@ -454,8 +454,9 @@ void hrule(FILE *outf, Outchoices *od) {
 }
 
 void include_file(FILE *outf, Outchoices *od, char *name, char type) {
-  extern char *block_start, *block_end;
   FILE *inf;
+  char buffer[BLOCKSIZE];
+  size_t n;
 
   if ((inf = my_fopen(name, (type == 'h')?"header file":"footer file")) !=
       NULL) {
@@ -465,9 +466,8 @@ void include_file(FILE *outf, Outchoices *od, char *name, char type) {
       if (od->outstyle == LATEX)
 	fputs("\\smallskip\n", outf);
     }
-    while (getmoredata(inf, block_start, BLOCKSIZE) != EOF)
-      fwrite((void *)block_start, 1,
-	     (size_t)((char *)block_end - (char *)block_start), outf);
+    while ((n = fread(buffer, 1, BLOCKSIZE, inf)))  /* single equals */
+      fwrite((void *)buffer, 1, n, outf);
     if (type == 'h') {
       hrule(outf, od);
       if (od->outstyle == LATEX)
@@ -700,20 +700,39 @@ int f3printf(FILE *outf, choice outstyle, double x, unsigned int width,
 
 void printbytes(FILE *outf, Outchoices *od, double bytes, unsigned int bmult,
 		unsigned int width, char sepchar) {
-  int by1, by2;
+
+  unsigned int dp = od->bytesdp;
+
+  int by1;
+  double by2, rounder;
   unsigned int j;
 
   if (bmult == 0)
     (void)f3printf(outf, od->outstyle, bytes, width, sepchar);
   else {
     for (j = 0; j < bmult; j++)
-      bytes /= 1024;
-    by1 = (int)bytes;
-    by2 = (int)(1000 * (bytes - (double)by1));
-    width = MAX(width, 3);
-    fprintf(outf, "%*d", width - 4, by1);
-    myputc(outf, od->decpt, od->outstyle);
-    fprintf(outf, "%03d", by2);
+      bytes /= 1024; /* divide bytes to get kilobytes, megabytes or whatever */
+
+    /* Add some amount in order to round to the correct number of decimal
+       places accurately: 0.5 for 0 d.p.s, 0.05 for 1 d.p. etc. */
+    rounder = 0.5;
+    for (j = 0; j < dp; j++)
+      rounder /= 10.0;
+    bytes += rounder;
+
+    if (dp == 0) {  /* fractional part not wanted */
+      fprintf(outf, "%*d", width, (int)bytes);
+    }
+    else {
+      by1 = (int)bytes;    /* whole number of kilo/mega/etc. bytes */
+      width -= MIN(width, dp + 1);  /* leave room for fractional part */
+      fprintf(outf, "%*d", width, by1);
+      by2 = (bytes - (double)by1);  /* fractional part */
+      for (j = 0; j < dp; j++)
+	by2 *= 10;
+      myputc(outf, od->decpt, od->outstyle);
+      fprintf(outf, "%0*d", dp, (int)by2);
+    }
   }
 }
 
@@ -844,9 +863,10 @@ void calcsizes(Outchoices *od, choice rep, unsigned int width[],
       *bmult = 0;
     }
     else {
-      *bmult = findbmult(maxb);
-      width[COL_BYTES] = MAX(7, htmlstrlen(lngstr[col2colhead[COL_BYTES] + 1],
-					   outstyle)
+      *bmult = findbmult(maxb, od->bytesdp);
+      width[COL_BYTES] = MAX(3 + od->bytesdp + (od->bytesdp != 0),
+			     htmlstrlen(lngstr[col2colhead[COL_BYTES] + 1],
+					outstyle)
 			     + htmlstrlen(lngstr[byteprefixabbr_ + *bmult],
 					  outstyle) - 1);
     }
@@ -860,8 +880,8 @@ void calcsizes(Outchoices *od, choice rep, unsigned int width[],
       *bmult7 = 0;
     }
     else {
-      *bmult7 = findbmult(maxb7);
-      width[COL_BYTES7] = MAX(7,
+      *bmult7 = findbmult(maxb7, od->bytesdp);
+      width[COL_BYTES7] = MAX(3 + od->bytesdp + (od->bytesdp != 0),
 			      htmlstrlen(lngstr[col2colhead[COL_BYTES7] + 1],
 					 outstyle)
 			      + htmlstrlen(lngstr[byteprefixabbr_ + *bmult7],
@@ -978,8 +998,9 @@ void declareunit(FILE *outf, Outchoices *od, char graphby, double unit,
     else if (outstyle == HTML) {
       mprintf(outf, pagewidth, "<img src=\"");
       htmlputs(outf, od, od->imagedir, IN_HREF);
-      mprintf(outf, pagewidth, "bar%c1%c%s\" alt=\"%c\">", od->barstyle,
-	      EXTSEP, od->pngimages?"png":"gif", markchar);
+      mprintf(outf, pagewidth, "bar%c1.%s\" alt=\"%c\">", od->barstyle,
+	      od->pngimages?"png":"gif", markchar);
+      /* Above: '.' not EXTSEP even on RISC OS */
     }
     else /* outstyle == LATEX */
       mprintf(outf, pagewidth, "\\barchart{1}");
@@ -1307,7 +1328,7 @@ void busyprintf(FILE *outf, Outchoices *od, choice rep, char *datefmt,
     if (od->rawbytes)
       bmult = 0;
     else
-      bmult = findbmult(bys);
+      bmult = findbmult(bys, od->bytesdp);
     if (outstyle == COMPUTER)
       fprintf(outf, "%s*BT%sB%s", compsep, compsep, compsep);
     printbytes(outf, od, bys, bmult, 0, sepchar);
@@ -1388,8 +1409,9 @@ void barchart(FILE *outf, Outchoices *od, char graphby, unsigned long reqs,
       while (y >= j) {
 	fputs("<img src=\"", outf);
 	htmlputs(outf, od, od->imagedir, IN_HREF);
-	fprintf(outf, "bar%c%d%c%s\" alt=\"", od->barstyle, j, EXTSEP,
-		od->pngimages?"png":"gif");
+	fprintf(outf, "bar%c%d.%s\" alt=\"", od->barstyle, j,
+		od->pngimages?"png":"gif");/* '.' not EXTSEP even on RISC OS */
+
 	if (first) {
 	  for (i = 0; i < y; i++)
 	    myputc(outf, od->markchar, outstyle);
@@ -1846,7 +1868,7 @@ void gensumlineb(FILE *outf, Outchoices *od, char codeletter, int namecode,
       fprintf(outf, "{\\bf %s%s} ", name, colon);
     else /* outstyle == COMPUTER */
       fprintf(outf, "x%s%c%c%s", compsep, name[0], name[1], compsep);
-    bm = (od->rawbytes)?0:findbmult(x);
+    bm = (od->rawbytes)?0:findbmult(x, od->bytesdp);
     printbytes(outf, od, x, bm, 0, od->sepchar);
     if (outstyle != COMPUTER) {
       if (bm > 0) {
@@ -1866,7 +1888,7 @@ void gensumlineb(FILE *outf, Outchoices *od, char codeletter, int namecode,
       }
       else {
 	fputs(" (", outf);
-	bm = (od->rawbytes)?0:findbmult(x7);
+	bm = (od->rawbytes)?0:findbmult(x7, od->bytesdp);
 	printbytes(outf, od, x7, bm, 0, od->sepchar);
 	if (bm > 0) {
 	  c = strchr(lngstr[xbytes_], '?');
@@ -2083,6 +2105,9 @@ FILE *piechart_init(char *filename) {
     return(pieoutf);
   }
   debug('F', "Opening %s as pie chart file", filename);
+#ifdef RISCOS
+  _swix(OS_File, _INR(0,2), 18, filename, 0xb60);  /* set filetype */
+#endif
 
   xsize = normalchart?XSIZE:SHORTXSIZE;
   ysize = normalchart?YSIZE:SHORTYSIZE;
@@ -2297,9 +2322,9 @@ void piechart_key(FILE *outf, Outchoices *od, int col, char *name,
   fputs("<br><img src=\"", outf);
   htmlputs(outf, od, od->imagedir, IN_HREF);
   if (col == NO_COLOURS)
-    fprintf(outf, "sqg%c%s", EXTSEP, extension);
-  else
-    fprintf(outf, "sq%d%c%s", col, EXTSEP, extension);
+    fprintf(outf, "sqg.%s", extension);
+  else         /* Above and below: '.' not EXTSEP even on RISC OS */
+    fprintf(outf, "sq%d.%s", col, extension);
   fputs("\" alt=\"\"> ", outf);
   do_aliasx(outf, od, name, aliashead);  /* alias and print */
   fputs("\n", outf);
@@ -2444,8 +2469,9 @@ void piechart(FILE *outf, Outchoices *od, choice rep, Hashindex *items,
      is closed, or the browser may fail to find the image. This is why printing
      the caption and key must be done twice; above here if normalchart, below
      here otherwise. */
-  fprintf(outf, "<p><img src=\"%s%s%c%s\" alt=\"\">\n", od->chartdir,
-	  anchorname[rep], EXTSEP, extension);
+  fprintf(outf, "<p><img src=\"%s%s.%s\" alt=\"\">\n", od->chartdir,
+	  anchorname[rep], extension);   /* '.' not EXTSEP even on RISC OS */
+
   if (!normalchart) {
     piechart_caption(outf, rep, od->chartby[G(rep)], lngstr);
     for (i = 0; i < NO_COLOURS; i++) {
