@@ -1,5 +1,5 @@
-/***             analog 5.24             http://www.analog.cx/             ***/
-/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
+/***             analog 5.32             http://www.analog.cx/             ***/
+/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2003 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
  *** with it. This program comes with no warranty, expressed or implied.   ***/
@@ -8,7 +8,7 @@
 
 #include "anlghea3.h"
 
-void process_data(Filelist *logfilep, FILE *lf, Hashtable **hash,
+void process_data(Logfile *logfilep, Hashtable **hash,
 		  Arraydata **arraydata, choice *count, choice *code2type,
 		  choice datacols[ITEM_NUMBER][OUTCOME_NUMBER][DATACOLS_NUMBER][2],
 		  choice data2cols[ITEM_NUMBER][DATA_NUMBER],
@@ -63,7 +63,7 @@ void process_data(Filelist *logfilep, FILE *lf, Hashtable **hash,
     else {
       if (count[INP_AM]) {
 	if (hour > 12) {
-	  corrupt_line(lf, logfilep, "Hour greater than 12", -1);
+	  corrupt_line(logfilep, "Hour greater than 12", -1);
 	  return;
 	}
 	else if (hour == 12)
@@ -75,7 +75,7 @@ void process_data(Filelist *logfilep, FILE *lf, Hashtable **hash,
 			logfilep->tz);
     }
     if (wanted == ERR) { /* corrupt date */
-      corrupt_line(lf, logfilep, "Corrupt date or time", -1);
+      corrupt_line(logfilep, "Corrupt date or time", -1);
       return;
     }
   }  /* end count[INP_DATE] > 0 */
@@ -109,10 +109,10 @@ void process_data(Filelist *logfilep, FILE *lf, Hashtable **hash,
 			  logfilep->prefixlen, logfilep->pvpos,
 			  (i == ITEM_FILE)?argshead:refargshead)) < 0) {
 	  if (j == -1)
-	    corrupt_line(lf, logfilep,
+	    corrupt_line(logfilep,
 			 "%v in file prefix but no VHOST in line", -1);
 	  else
-	    corrupt_line(lf, logfilep, "Filename too long", -1);
+	    corrupt_line(logfilep, "Filename too long", -1);
 	  return;
 	}
       }
@@ -336,12 +336,12 @@ void process_data(Filelist *logfilep, FILE *lf, Hashtable **hash,
   }      /* end if outcome != INFO */
 }
 
-void corrupt_line(FILE *lf, Filelist *logfilep, char *message, ptrdiff_t n) {
+void corrupt_line(Logfile *logfilep, char *message, ptrdiff_t n) {
   extern FILE *errfile;
   extern char *debug_args, *record_start, *pos;
 
   pos = record_start;
-  parsenonnewline(lf);  /* skip to after next newline */
+  parsenonnewline(logfilep);  /* skip to after next newline */
   *pos = '\0';
   if (pos - record_start > 500)  /* debug might only handle 509 chars */
     *(record_start + 500) = '\0';
@@ -358,7 +358,7 @@ void corrupt_line(FILE *lf, Filelist *logfilep, char *message, ptrdiff_t n) {
   }
   logfilep->data[LOGDATA_CORRUPT]++;
   *pos = '\n';
-  (void)parsenewline(lf, NULL, '\0');
+  (void)parsenewline(logfilep, NULL, '\0');
 }
 
 void arrayscore(Arraydata *array, double amount, unsigned long reqs,
