@@ -1,5 +1,5 @@
-/***             analog 5.24             http://www.analog.cx/             ***/
-/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
+/***             analog 5.32             http://www.analog.cx/             ***/
+/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2003 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
  *** with it. This program comes with no warranty, expressed or implied.   ***/
@@ -112,6 +112,9 @@ void report_compile(void) {
 #ifdef WIN32DIRENT
   printf("  Win32 dirent included\n");
 #else
+#ifdef RISCOSDIRENT
+  printf("  RISC OS dirent included\n");
+#else
 #ifdef NOGLOB
   printf("  POSIX.1 dirent included\n");
 #else
@@ -121,6 +124,7 @@ void report_compile(void) {
 #endif
 #endif
 #endif
+#endif
 #ifdef NOOPEN
   printf("  No open() function\n");
 #else
@@ -200,8 +204,8 @@ void report_debug(char *type, char *arg, char *fullset) {
   }
 }
 
-void report_logfiles(Filelist *logfile, logical cache) {
-  Filelist *lf;
+void report_logfiles(Logfile *logfile, logical cache) {
+  Logfile *lf;
 
   printf("Reading %sfiles:\n", cache?"cache ":"log");
   if (logfile == NULL)
@@ -601,7 +605,10 @@ void report_outopts(Outchoices *od) {
       else
 	printf("Host URL is %s\n", od->hosturl);
     }
-    printf("Displaying %s bytes\n", (od->rawbytes)?"exact":"abbreviated");
+    if (od->rawbytes)
+      printf("Displaying exact bytes\n");
+    else
+      printf("Displaying bytes rounded to %u decimal places\n", od->bytesdp);
     if (od->outstyle != COMPUTER) {
       printf("The character for graph plotting is: %c\n", od->markchar);
       report_sep(od->sepchar, "thousands separator");
