@@ -1,5 +1,5 @@
-/***             analog 5.24             http://www.analog.cx/             ***/
-/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
+/***             analog 5.32             http://www.analog.cx/             ***/
+/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2003 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
  *** with it. This program comes with no warranty, expressed or implied.   ***/
@@ -119,7 +119,9 @@ void calcfloor(unsigned long *min, double *dmin, choice *filterby,
       *dmin *= (double)totr / 100.0;  /* NB dmin < 0 => qual == '\0' */
     else if (floor->qual == ':')
       *dmin *= (double)maxr / 100.0;
-    *min = (unsigned long)(*dmin + 1 - EPSILON);
+    /* negative doubles may not convertable to unsigned integral types --
+       C spec 6.2.1.3 */
+    *min = (*dmin >= 0)?(unsigned long)(*dmin + 1 - EPSILON):0;
   }
   else if (*filterby == REQUESTS7) {
     *filterby = requests7;
@@ -127,7 +129,7 @@ void calcfloor(unsigned long *min, double *dmin, choice *filterby,
       *dmin *= (double)totr7 / 100.0;
     else if (floor->qual == ':')
       *dmin *= (double)maxr7 / 100.0;
-    *min = (unsigned long)(*dmin + 1 - EPSILON);
+    *min = (*dmin >= 0)?(unsigned long)(*dmin + 1 - EPSILON):0;
   }
   else if (*filterby == PAGES) {
     *filterby = pages;
@@ -135,7 +137,7 @@ void calcfloor(unsigned long *min, double *dmin, choice *filterby,
       *dmin *= (double)totp / 100.0;
     else if (floor->qual == ':')
       *dmin *= (double)maxp / 100.0;
-    *min = (unsigned long)(*dmin + 1 - EPSILON);
+    *min = (*dmin >= 0)?(unsigned long)(*dmin + 1 - EPSILON):0;
   }
   else if (*filterby == PAGES7) {
     *filterby = pages7;
@@ -143,7 +145,7 @@ void calcfloor(unsigned long *min, double *dmin, choice *filterby,
       *dmin *= (double)totp7 / 100.0;
     else if (floor->qual == ':')
       *dmin *= (double)maxp7 / 100.0;
-    *min = (unsigned long)(*dmin + 1 - EPSILON);
+    *min = (*dmin >= 0)?(unsigned long)(*dmin + 1 - EPSILON):0;
   }
   else if (*filterby == BYTES) {
     if (floor->qual == '%')
@@ -169,11 +171,11 @@ void calcfloor(unsigned long *min, double *dmin, choice *filterby,
   }
   else if (*filterby == DATESORT) {
     *filterby = date;
-    *min = (unsigned long)(*dmin + 1 - EPSILON);
+    *min = (*dmin >= 0)?(unsigned long)(*dmin + 1 - EPSILON):0;
   }
   else { /* *filterby == FIRSTDATE */
     *filterby = firstd;
-    *min = (unsigned long)(*dmin + 1 - EPSILON);
+    *min = (*dmin >= 0)?(unsigned long)(*dmin + 1 - EPSILON):0;
   }
 }
 
@@ -339,7 +341,7 @@ void my_sort(Hashindex **gooditems, Hashindex **baditems, Strlist *partname,
       if (count > 0) {
 	if (sortby == BYTES)
 	  ans = my_mergesort(ans, count, sortby, &mergeb);
-	if (sortby == BYTES7)
+	else if (sortby == BYTES7)
 	  ans = my_mergesort(ans, count, sortby, &mergeb7);
 	else if (sortby == ALPHABETICAL) {
 	  if (alphaback)
