@@ -1,5 +1,5 @@
-/***             analog 5.24             http://www.analog.cx/             ***/
-/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
+/***             analog 5.32             http://www.analog.cx/             ***/
+/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2003 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
  *** with it. This program comes with no warranty, expressed or implied.   ***/
@@ -765,6 +765,10 @@ void Bnextname(char **name, char **nameend, char *whole, void *arg) {
 	((*name = strstr(whole, "mosaic")) != NULL && (len = 6)) ||
 	((*name = strstr(whole, "Konqueror")) != NULL && (len = 9)) ||
 	((*name = strstr(whole, "Galeon")) != NULL && (len = 6)) ||
+	((*name = strstr(whole, "Phoenix")) != NULL && (len = 7)) ||
+	((*name = strstr(whole, "Chimera")) != NULL && (len = 7)) ||
+	((*name = strstr(whole, "Camino")) != NULL && (len = 6)) ||
+	((*name = strstr(whole, "Safari")) != NULL && (len = 6)) ||
 	((*name = strstr(whole, "WebTV")) != NULL && (len = 5)) ||
 	((*name = strstr(whole, "Opera")) != NULL && (len = 5)) ||
 	((*name = strstr(whole, "MSIE")) != NULL && (len = 4))) {
@@ -887,14 +891,8 @@ void Pnextname(char **name, char **nameend, char *whole, void *arg) {
     }
 
     /* Now non-Windows operating systems */
-    else if ((c = strstr(whole, "Mac")) != NULL) {
-      if (strstr(c + 3, "68"))
-	*name = "Macintosh:Macintosh 68k";
-      else if (strstr(c + 3, "PPC") || strstr(c + 3, "PowerPC"))
-	*name = "Macintosh:Macintosh PowerPC";
-      else
-	*name = "Macintosh:Unknown Macintosh";
-    }
+    else if ((c = strstr(whole, "Mac")) != NULL)
+	*name = "Macintosh";
     else if (strstr(whole, "Linux") != NULL || strstr(whole, "linux") != NULL)
       *name = "Unix:Linux";
     else if (strstr(whole, "BSD") != NULL)
