@@ -1,5 +1,5 @@
-/***             analog 5.24             http://www.analog.cx/             ***/
-/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
+/***             analog 5.32             http://www.analog.cx/             ***/
+/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2003 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
  *** with it. This program comes with no warranty, expressed or implied.   ***/
@@ -274,16 +274,47 @@ unsigned int log10x(double d) {
   return(j);
 }
 
-unsigned int findbmult(double d) {
+/* If 'd' bytes are displayed to 'dp' decimal places, should they be written
+   as kilobytes, megabytes, or what? */
+unsigned int findbmult(double d, unsigned int dp) {
   unsigned int j;
+  double threshold;
 
   if (d < 1024)
     return(0);  /* see also in calcsizes() */
-  for (j = 0; d >= 1000.0; d /= 1024.0)
+
+  /* Bytes will be rounded to 'dp' decimal places. So the theshold at which
+     we move to a new multiplier is 999.5 if dp = 0, 999.95 if dp = 1 etc. */
+  threshold = 0.5;
+  for (j = 0; j < dp; j++)
+    threshold /= 10.0;
+  threshold = 1000.0 - threshold;
+
+  /* Now we can find the multiplier */
+  for (j = 0; d >= threshold; d /= 1024.0)
     j++;
   return(j);
 }
 
+/* Convert a string to integer between 0 and 255, with some error checking
+   built in. Returns -1 if string empty, or not all digits, or greater than
+   255. */
+int atoi255(const char *s) {
+  int ans;
+
+  if (*s == '\0')
+    return(-1);
+  for (ans = 0; ISDIGIT(*s); s++) {
+    ans *= 10;
+    ans += *s - '0';
+    if (ans > 255)
+      return(-1);
+  }
+  if (*s != '\0')
+    return(-1);
+  return(ans);
+}
+
 unsigned long arraymaxl(unsigned long *x, unsigned int size) {
   unsigned long y;
   unsigned int i;
@@ -756,24 +787,62 @@ logical headcasematch(char *s, char *p) {  /* same, only case insensitive */
   return(TRUE);
 }
 
+/* Does a hostname match an IP address range? */
+logical matchiprange(char *s, unsigned long minaddr, unsigned long maxaddr)
+{
+  unsigned long addr;
+  int n, octet;
+
+  /* Turn this host into a long. This is basically just the simple case from
+     parseiprange() (including atoi255()), but a much faster version. */
+
+  for (addr = 0, octet = 0; octet < 4; octet++) {
+    if (!ISDIGIT(*s))
+      return(FALSE);
+    for (n = 0; ISDIGIT(*s); s++) {
+      n *= 10;
+      n += *s - '0';
+      if (n > 255)
+	return(FALSE);
+    }
+    if (octet < 3) {
+      if (*s == '.')
+	s++;
+      else
+	return(FALSE);
+    }
+    addr <<= 8;
+    addr += n;
+  }
+
+  if (*s != '\0')
+    return(FALSE);
+
+  /* Is it in the right range? */
+  return (minaddr <= addr && addr <= maxaddr);
+}
+
 /* Is an item included according to an INCLUDE/EXCLUDE list? */
 logical included(char *name, logical ispage, Include *listhead) {
-  logical is_regex;
+  logical is_ipaddr, is_regex, matches;
   Include *lp, *lastlp;
 
   if (listhead == NULL)
     return(TRUE);
 
   for (lp = listhead; lp != NULL; TO_NEXT(lp)) {
+    is_ipaddr = IS_IPADDRT(lp->type);
     is_regex = IS_REGEXT(lp->type);
-    if (!is_regex && STREQ((char *)(lp->name), "pages")) {
+    if (!is_regex && !is_ipaddr && STREQ((char *)(lp->name), "pages"))
       /* 'pages' is made case insensitive at config time */
-      if (ispage)
-	return(IS_INC(lp->type));
-    }
-    else if (matchq(name,
-		    is_regex?((void *)(lp->pattern)):((void *)(lp->name)),
-		    is_regex, NULL))
+      matches = ispage;
+    else if (is_ipaddr)
+      matches = matchiprange(name, lp->minaddr, lp->maxaddr);
+    else
+      matches = matchq(name,
+		       is_regex?((void *)(lp->pattern)):((void *)(lp->name)),
+		       is_regex, NULL);
+    if (matches)
       return(IS_INC(lp->type));
     lastlp = lp;
   }
